# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ReportingV3PurchaseRefundDetailsGet200ResponseRequestDetails(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'request_id': 'str',
        'cybersource_merchant_id': 'str',
        'processor_merchant_id': 'str',
        'group_name': 'str',
        'transaction_reference_number': 'str',
        'merchant_reference_number': 'str'
    }

    attribute_map = {
        'request_id': 'requestId',
        'cybersource_merchant_id': 'cybersourceMerchantId',
        'processor_merchant_id': 'processorMerchantId',
        'group_name': 'groupName',
        'transaction_reference_number': 'transactionReferenceNumber',
        'merchant_reference_number': 'merchantReferenceNumber'
    }

    def __init__(self, request_id=None, cybersource_merchant_id=None, processor_merchant_id=None, group_name=None, transaction_reference_number=None, merchant_reference_number=None):
        """
        ReportingV3PurchaseRefundDetailsGet200ResponseRequestDetails - a model defined in Swagger
        """

        self._request_id = None
        self._cybersource_merchant_id = None
        self._processor_merchant_id = None
        self._group_name = None
        self._transaction_reference_number = None
        self._merchant_reference_number = None

        if request_id is not None:
          self.request_id = request_id
        if cybersource_merchant_id is not None:
          self.cybersource_merchant_id = cybersource_merchant_id
        if processor_merchant_id is not None:
          self.processor_merchant_id = processor_merchant_id
        if group_name is not None:
          self.group_name = group_name
        if transaction_reference_number is not None:
          self.transaction_reference_number = transaction_reference_number
        if merchant_reference_number is not None:
          self.merchant_reference_number = merchant_reference_number

    @property
    def request_id(self):
        """
        Gets the request_id of this ReportingV3PurchaseRefundDetailsGet200ResponseRequestDetails.
        An unique identification number assigned by CyberSource to identify the submitted request.

        :return: The request_id of this ReportingV3PurchaseRefundDetailsGet200ResponseRequestDetails.
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """
        Sets the request_id of this ReportingV3PurchaseRefundDetailsGet200ResponseRequestDetails.
        An unique identification number assigned by CyberSource to identify the submitted request.

        :param request_id: The request_id of this ReportingV3PurchaseRefundDetailsGet200ResponseRequestDetails.
        :type: str
        """

        self._request_id = request_id

    @property
    def cybersource_merchant_id(self):
        """
        Gets the cybersource_merchant_id of this ReportingV3PurchaseRefundDetailsGet200ResponseRequestDetails.
        Cybersource Merchant Id

        :return: The cybersource_merchant_id of this ReportingV3PurchaseRefundDetailsGet200ResponseRequestDetails.
        :rtype: str
        """
        return self._cybersource_merchant_id

    @cybersource_merchant_id.setter
    def cybersource_merchant_id(self, cybersource_merchant_id):
        """
        Sets the cybersource_merchant_id of this ReportingV3PurchaseRefundDetailsGet200ResponseRequestDetails.
        Cybersource Merchant Id

        :param cybersource_merchant_id: The cybersource_merchant_id of this ReportingV3PurchaseRefundDetailsGet200ResponseRequestDetails.
        :type: str
        """

        self._cybersource_merchant_id = cybersource_merchant_id

    @property
    def processor_merchant_id(self):
        """
        Gets the processor_merchant_id of this ReportingV3PurchaseRefundDetailsGet200ResponseRequestDetails.
        Cybersource Processor Merchant Id

        :return: The processor_merchant_id of this ReportingV3PurchaseRefundDetailsGet200ResponseRequestDetails.
        :rtype: str
        """
        return self._processor_merchant_id

    @processor_merchant_id.setter
    def processor_merchant_id(self, processor_merchant_id):
        """
        Sets the processor_merchant_id of this ReportingV3PurchaseRefundDetailsGet200ResponseRequestDetails.
        Cybersource Processor Merchant Id

        :param processor_merchant_id: The processor_merchant_id of this ReportingV3PurchaseRefundDetailsGet200ResponseRequestDetails.
        :type: str
        """

        self._processor_merchant_id = processor_merchant_id

    @property
    def group_name(self):
        """
        Gets the group_name of this ReportingV3PurchaseRefundDetailsGet200ResponseRequestDetails.
        Group Name

        :return: The group_name of this ReportingV3PurchaseRefundDetailsGet200ResponseRequestDetails.
        :rtype: str
        """
        return self._group_name

    @group_name.setter
    def group_name(self, group_name):
        """
        Sets the group_name of this ReportingV3PurchaseRefundDetailsGet200ResponseRequestDetails.
        Group Name

        :param group_name: The group_name of this ReportingV3PurchaseRefundDetailsGet200ResponseRequestDetails.
        :type: str
        """

        self._group_name = group_name

    @property
    def transaction_reference_number(self):
        """
        Gets the transaction_reference_number of this ReportingV3PurchaseRefundDetailsGet200ResponseRequestDetails.
        Transaction Reference Number

        :return: The transaction_reference_number of this ReportingV3PurchaseRefundDetailsGet200ResponseRequestDetails.
        :rtype: str
        """
        return self._transaction_reference_number

    @transaction_reference_number.setter
    def transaction_reference_number(self, transaction_reference_number):
        """
        Sets the transaction_reference_number of this ReportingV3PurchaseRefundDetailsGet200ResponseRequestDetails.
        Transaction Reference Number

        :param transaction_reference_number: The transaction_reference_number of this ReportingV3PurchaseRefundDetailsGet200ResponseRequestDetails.
        :type: str
        """

        self._transaction_reference_number = transaction_reference_number

    @property
    def merchant_reference_number(self):
        """
        Gets the merchant_reference_number of this ReportingV3PurchaseRefundDetailsGet200ResponseRequestDetails.
        Merchant Reference Number

        :return: The merchant_reference_number of this ReportingV3PurchaseRefundDetailsGet200ResponseRequestDetails.
        :rtype: str
        """
        return self._merchant_reference_number

    @merchant_reference_number.setter
    def merchant_reference_number(self, merchant_reference_number):
        """
        Sets the merchant_reference_number of this ReportingV3PurchaseRefundDetailsGet200ResponseRequestDetails.
        Merchant Reference Number

        :param merchant_reference_number: The merchant_reference_number of this ReportingV3PurchaseRefundDetailsGet200ResponseRequestDetails.
        :type: str
        """

        self._merchant_reference_number = merchant_reference_number

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ReportingV3PurchaseRefundDetailsGet200ResponseRequestDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class TssV2TransactionsPost201ResponseEmbeddedApplicationInformationApplications(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'reason_code': 'str',
        'r_code': 'str',
        'r_flag': 'str',
        'reconciliation_id': 'str',
        'r_message': 'str',
        'return_code': 'int'
    }

    attribute_map = {
        'name': 'name',
        'reason_code': 'reasonCode',
        'r_code': 'rCode',
        'r_flag': 'rFlag',
        'reconciliation_id': 'reconciliationId',
        'r_message': 'rMessage',
        'return_code': 'returnCode'
    }

    def __init__(self, name=None, reason_code=None, r_code=None, r_flag=None, reconciliation_id=None, r_message=None, return_code=None):
        """
        TssV2TransactionsPost201ResponseEmbeddedApplicationInformationApplications - a model defined in Swagger
        """

        self._name = None
        self._reason_code = None
        self._r_code = None
        self._r_flag = None
        self._reconciliation_id = None
        self._r_message = None
        self._return_code = None

        if name is not None:
          self.name = name
        if reason_code is not None:
          self.reason_code = reason_code
        if r_code is not None:
          self.r_code = r_code
        if r_flag is not None:
          self.r_flag = r_flag
        if reconciliation_id is not None:
          self.reconciliation_id = reconciliation_id
        if r_message is not None:
          self.r_message = r_message
        if return_code is not None:
          self.return_code = return_code

    @property
    def name(self):
        """
        Gets the name of this TssV2TransactionsPost201ResponseEmbeddedApplicationInformationApplications.
        The name of the CyberSource transaction type (such as CC settlement or CC authorization) that the merchant wants to process in a transaction request. More than one transaction type can included in a transaction request. Each transaction type separately returns their own status, reasonCode, rCode, and rFlag messages. 

        :return: The name of this TssV2TransactionsPost201ResponseEmbeddedApplicationInformationApplications.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this TssV2TransactionsPost201ResponseEmbeddedApplicationInformationApplications.
        The name of the CyberSource transaction type (such as CC settlement or CC authorization) that the merchant wants to process in a transaction request. More than one transaction type can included in a transaction request. Each transaction type separately returns their own status, reasonCode, rCode, and rFlag messages. 

        :param name: The name of this TssV2TransactionsPost201ResponseEmbeddedApplicationInformationApplications.
        :type: str
        """

        self._name = name

    @property
    def reason_code(self):
        """
        Gets the reason_code of this TssV2TransactionsPost201ResponseEmbeddedApplicationInformationApplications.
        3-digit reason code that indicates why the customer profile payment succeeded or failed.

        :return: The reason_code of this TssV2TransactionsPost201ResponseEmbeddedApplicationInformationApplications.
        :rtype: str
        """
        return self._reason_code

    @reason_code.setter
    def reason_code(self, reason_code):
        """
        Sets the reason_code of this TssV2TransactionsPost201ResponseEmbeddedApplicationInformationApplications.
        3-digit reason code that indicates why the customer profile payment succeeded or failed.

        :param reason_code: The reason_code of this TssV2TransactionsPost201ResponseEmbeddedApplicationInformationApplications.
        :type: str
        """

        self._reason_code = reason_code

    @property
    def r_code(self):
        """
        Gets the r_code of this TssV2TransactionsPost201ResponseEmbeddedApplicationInformationApplications.
        Indicates whether the service request was successful. Possible values:  - `-1`: An error occurred. - `0`: The request was declined. - `1`: The request was successful. 

        :return: The r_code of this TssV2TransactionsPost201ResponseEmbeddedApplicationInformationApplications.
        :rtype: str
        """
        return self._r_code

    @r_code.setter
    def r_code(self, r_code):
        """
        Sets the r_code of this TssV2TransactionsPost201ResponseEmbeddedApplicationInformationApplications.
        Indicates whether the service request was successful. Possible values:  - `-1`: An error occurred. - `0`: The request was declined. - `1`: The request was successful. 

        :param r_code: The r_code of this TssV2TransactionsPost201ResponseEmbeddedApplicationInformationApplications.
        :type: str
        """

        self._r_code = r_code

    @property
    def r_flag(self):
        """
        Gets the r_flag of this TssV2TransactionsPost201ResponseEmbeddedApplicationInformationApplications.
        One-word description of the result of the application. 

        :return: The r_flag of this TssV2TransactionsPost201ResponseEmbeddedApplicationInformationApplications.
        :rtype: str
        """
        return self._r_flag

    @r_flag.setter
    def r_flag(self, r_flag):
        """
        Sets the r_flag of this TssV2TransactionsPost201ResponseEmbeddedApplicationInformationApplications.
        One-word description of the result of the application. 

        :param r_flag: The r_flag of this TssV2TransactionsPost201ResponseEmbeddedApplicationInformationApplications.
        :type: str
        """

        self._r_flag = r_flag

    @property
    def reconciliation_id(self):
        """
        Gets the reconciliation_id of this TssV2TransactionsPost201ResponseEmbeddedApplicationInformationApplications.
        Reference number that you use to reconcile your CyberSource reports with your processor reports. 

        :return: The reconciliation_id of this TssV2TransactionsPost201ResponseEmbeddedApplicationInformationApplications.
        :rtype: str
        """
        return self._reconciliation_id

    @reconciliation_id.setter
    def reconciliation_id(self, reconciliation_id):
        """
        Sets the reconciliation_id of this TssV2TransactionsPost201ResponseEmbeddedApplicationInformationApplications.
        Reference number that you use to reconcile your CyberSource reports with your processor reports. 

        :param reconciliation_id: The reconciliation_id of this TssV2TransactionsPost201ResponseEmbeddedApplicationInformationApplications.
        :type: str
        """

        self._reconciliation_id = reconciliation_id

    @property
    def r_message(self):
        """
        Gets the r_message of this TssV2TransactionsPost201ResponseEmbeddedApplicationInformationApplications.
        Message that explains the reply flag for the application. 

        :return: The r_message of this TssV2TransactionsPost201ResponseEmbeddedApplicationInformationApplications.
        :rtype: str
        """
        return self._r_message

    @r_message.setter
    def r_message(self, r_message):
        """
        Sets the r_message of this TssV2TransactionsPost201ResponseEmbeddedApplicationInformationApplications.
        Message that explains the reply flag for the application. 

        :param r_message: The r_message of this TssV2TransactionsPost201ResponseEmbeddedApplicationInformationApplications.
        :type: str
        """

        self._r_message = r_message

    @property
    def return_code(self):
        """
        Gets the return_code of this TssV2TransactionsPost201ResponseEmbeddedApplicationInformationApplications.
        The description for this field is not available.

        :return: The return_code of this TssV2TransactionsPost201ResponseEmbeddedApplicationInformationApplications.
        :rtype: int
        """
        return self._return_code

    @return_code.setter
    def return_code(self, return_code):
        """
        Sets the return_code of this TssV2TransactionsPost201ResponseEmbeddedApplicationInformationApplications.
        The description for this field is not available.

        :param return_code: The return_code of this TssV2TransactionsPost201ResponseEmbeddedApplicationInformationApplications.
        :type: int
        """

        self._return_code = return_code

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TssV2TransactionsPost201ResponseEmbeddedApplicationInformationApplications):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class PtsV2PaymentsPost201ResponseLinks(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        '_self': 'PtsV2PaymentsPost201ResponseLinksSelf',
        'reversal': 'PtsV2PaymentsPost201ResponseLinksSelf',
        'capture': 'PtsV2PaymentsPost201ResponseLinksSelf',
        'customer': 'PtsV2PaymentsPost201ResponseLinksSelf',
        'payment_instrument': 'PtsV2PaymentsPost201ResponseLinksSelf',
        'shipping_address': 'PtsV2PaymentsPost201ResponseLinksSelf',
        'instrument_identifier': 'PtsV2PaymentsPost201ResponseLinksSelf'
    }

    attribute_map = {
        '_self': 'self',
        'reversal': 'reversal',
        'capture': 'capture',
        'customer': 'customer',
        'payment_instrument': 'paymentInstrument',
        'shipping_address': 'shippingAddress',
        'instrument_identifier': 'instrumentIdentifier'
    }

    def __init__(self, _self=None, reversal=None, capture=None, customer=None, payment_instrument=None, shipping_address=None, instrument_identifier=None):
        """
        PtsV2PaymentsPost201ResponseLinks - a model defined in Swagger
        """

        self.__self = None
        self._reversal = None
        self._capture = None
        self._customer = None
        self._payment_instrument = None
        self._shipping_address = None
        self._instrument_identifier = None

        if _self is not None:
          self._self = _self
        if reversal is not None:
          self.reversal = reversal
        if capture is not None:
          self.capture = capture
        if customer is not None:
          self.customer = customer
        if payment_instrument is not None:
          self.payment_instrument = payment_instrument
        if shipping_address is not None:
          self.shipping_address = shipping_address
        if instrument_identifier is not None:
          self.instrument_identifier = instrument_identifier

    @property
    def _self(self):
        """
        Gets the _self of this PtsV2PaymentsPost201ResponseLinks.

        :return: The _self of this PtsV2PaymentsPost201ResponseLinks.
        :rtype: PtsV2PaymentsPost201ResponseLinksSelf
        """
        return self.__self

    @_self.setter
    def _self(self, _self):
        """
        Sets the _self of this PtsV2PaymentsPost201ResponseLinks.

        :param _self: The _self of this PtsV2PaymentsPost201ResponseLinks.
        :type: PtsV2PaymentsPost201ResponseLinksSelf
        """

        self.__self = _self

    @property
    def reversal(self):
        """
        Gets the reversal of this PtsV2PaymentsPost201ResponseLinks.

        :return: The reversal of this PtsV2PaymentsPost201ResponseLinks.
        :rtype: PtsV2PaymentsPost201ResponseLinksSelf
        """
        return self._reversal

    @reversal.setter
    def reversal(self, reversal):
        """
        Sets the reversal of this PtsV2PaymentsPost201ResponseLinks.

        :param reversal: The reversal of this PtsV2PaymentsPost201ResponseLinks.
        :type: PtsV2PaymentsPost201ResponseLinksSelf
        """

        self._reversal = reversal

    @property
    def capture(self):
        """
        Gets the capture of this PtsV2PaymentsPost201ResponseLinks.

        :return: The capture of this PtsV2PaymentsPost201ResponseLinks.
        :rtype: PtsV2PaymentsPost201ResponseLinksSelf
        """
        return self._capture

    @capture.setter
    def capture(self, capture):
        """
        Sets the capture of this PtsV2PaymentsPost201ResponseLinks.

        :param capture: The capture of this PtsV2PaymentsPost201ResponseLinks.
        :type: PtsV2PaymentsPost201ResponseLinksSelf
        """

        self._capture = capture

    @property
    def customer(self):
        """
        Gets the customer of this PtsV2PaymentsPost201ResponseLinks.

        :return: The customer of this PtsV2PaymentsPost201ResponseLinks.
        :rtype: PtsV2PaymentsPost201ResponseLinksSelf
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """
        Sets the customer of this PtsV2PaymentsPost201ResponseLinks.

        :param customer: The customer of this PtsV2PaymentsPost201ResponseLinks.
        :type: PtsV2PaymentsPost201ResponseLinksSelf
        """

        self._customer = customer

    @property
    def payment_instrument(self):
        """
        Gets the payment_instrument of this PtsV2PaymentsPost201ResponseLinks.

        :return: The payment_instrument of this PtsV2PaymentsPost201ResponseLinks.
        :rtype: PtsV2PaymentsPost201ResponseLinksSelf
        """
        return self._payment_instrument

    @payment_instrument.setter
    def payment_instrument(self, payment_instrument):
        """
        Sets the payment_instrument of this PtsV2PaymentsPost201ResponseLinks.

        :param payment_instrument: The payment_instrument of this PtsV2PaymentsPost201ResponseLinks.
        :type: PtsV2PaymentsPost201ResponseLinksSelf
        """

        self._payment_instrument = payment_instrument

    @property
    def shipping_address(self):
        """
        Gets the shipping_address of this PtsV2PaymentsPost201ResponseLinks.

        :return: The shipping_address of this PtsV2PaymentsPost201ResponseLinks.
        :rtype: PtsV2PaymentsPost201ResponseLinksSelf
        """
        return self._shipping_address

    @shipping_address.setter
    def shipping_address(self, shipping_address):
        """
        Sets the shipping_address of this PtsV2PaymentsPost201ResponseLinks.

        :param shipping_address: The shipping_address of this PtsV2PaymentsPost201ResponseLinks.
        :type: PtsV2PaymentsPost201ResponseLinksSelf
        """

        self._shipping_address = shipping_address

    @property
    def instrument_identifier(self):
        """
        Gets the instrument_identifier of this PtsV2PaymentsPost201ResponseLinks.

        :return: The instrument_identifier of this PtsV2PaymentsPost201ResponseLinks.
        :rtype: PtsV2PaymentsPost201ResponseLinksSelf
        """
        return self._instrument_identifier

    @instrument_identifier.setter
    def instrument_identifier(self, instrument_identifier):
        """
        Sets the instrument_identifier of this PtsV2PaymentsPost201ResponseLinks.

        :param instrument_identifier: The instrument_identifier of this PtsV2PaymentsPost201ResponseLinks.
        :type: PtsV2PaymentsPost201ResponseLinksSelf
        """

        self._instrument_identifier = instrument_identifier

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PtsV2PaymentsPost201ResponseLinks):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Tmsv2customersEmbeddedDefaultPaymentInstrumentCard(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'expiration_month': 'str',
        'expiration_year': 'str',
        'type': 'str',
        'issue_number': 'str',
        'start_month': 'str',
        'start_year': 'str',
        'use_as': 'str',
        'tokenized_information': 'Tmsv2customersEmbeddedDefaultPaymentInstrumentCardTokenizedInformation'
    }

    attribute_map = {
        'expiration_month': 'expirationMonth',
        'expiration_year': 'expirationYear',
        'type': 'type',
        'issue_number': 'issueNumber',
        'start_month': 'startMonth',
        'start_year': 'startYear',
        'use_as': 'useAs',
        'tokenized_information': 'tokenizedInformation'
    }

    def __init__(self, expiration_month=None, expiration_year=None, type=None, issue_number=None, start_month=None, start_year=None, use_as=None, tokenized_information=None):
        """
        Tmsv2customersEmbeddedDefaultPaymentInstrumentCard - a model defined in Swagger
        """

        self._expiration_month = None
        self._expiration_year = None
        self._type = None
        self._issue_number = None
        self._start_month = None
        self._start_year = None
        self._use_as = None
        self._tokenized_information = None

        if expiration_month is not None:
          self.expiration_month = expiration_month
        if expiration_year is not None:
          self.expiration_year = expiration_year
        if type is not None:
          self.type = type
        if issue_number is not None:
          self.issue_number = issue_number
        if start_month is not None:
          self.start_month = start_month
        if start_year is not None:
          self.start_year = start_year
        if use_as is not None:
          self.use_as = use_as
        if tokenized_information is not None:
          self.tokenized_information = tokenized_information

    @property
    def expiration_month(self):
        """
        Gets the expiration_month of this Tmsv2customersEmbeddedDefaultPaymentInstrumentCard.
        Two-digit month in which the payment card expires.  Format: `MM`.  Valid values: `01` through `12`. 

        :return: The expiration_month of this Tmsv2customersEmbeddedDefaultPaymentInstrumentCard.
        :rtype: str
        """
        return self._expiration_month

    @expiration_month.setter
    def expiration_month(self, expiration_month):
        """
        Sets the expiration_month of this Tmsv2customersEmbeddedDefaultPaymentInstrumentCard.
        Two-digit month in which the payment card expires.  Format: `MM`.  Valid values: `01` through `12`. 

        :param expiration_month: The expiration_month of this Tmsv2customersEmbeddedDefaultPaymentInstrumentCard.
        :type: str
        """
        if expiration_month is not None and len(expiration_month) > 2:
            raise ValueError("Invalid value for `expiration_month`, length must be less than or equal to `2`")

        self._expiration_month = expiration_month

    @property
    def expiration_year(self):
        """
        Gets the expiration_year of this Tmsv2customersEmbeddedDefaultPaymentInstrumentCard.
        Four-digit year in which the credit card expires.  Format: `YYYY`. 

        :return: The expiration_year of this Tmsv2customersEmbeddedDefaultPaymentInstrumentCard.
        :rtype: str
        """
        return self._expiration_year

    @expiration_year.setter
    def expiration_year(self, expiration_year):
        """
        Sets the expiration_year of this Tmsv2customersEmbeddedDefaultPaymentInstrumentCard.
        Four-digit year in which the credit card expires.  Format: `YYYY`. 

        :param expiration_year: The expiration_year of this Tmsv2customersEmbeddedDefaultPaymentInstrumentCard.
        :type: str
        """
        if expiration_year is not None and len(expiration_year) > 4:
            raise ValueError("Invalid value for `expiration_year`, length must be less than or equal to `4`")

        self._expiration_year = expiration_year

    @property
    def type(self):
        """
        Gets the type of this Tmsv2customersEmbeddedDefaultPaymentInstrumentCard.
        Value that indicates the card type. Valid v2 : v1 - description values:   * 001 : visa   * 002 : mastercard - Eurocard—European regional brand of Mastercard   * 003 : american express   * 004 : discover   * 005 : diners club   * 006 : carte blanche   * 007 : jcb   * 008 : optima   * 011 : twinpay credit   * 012 : twinpay debit   * 013 : walmart   * 014 : enRoute   * 015 : lowes consumer   * 016 : home depot consumer   * 017 : mbna   * 018 : dicks sportswear   * 019 : casual corner   * 020 : sears   * 021 : jal   * 023 : disney   * 024 : maestro uk domestic   * 025 : sams club consumer   * 026 : sams club business   * 028 : bill me later   * 029 : bebe   * 030 : restoration hardware   * 031 : delta online — use this value only for Ingenico ePayments. For other processors, use 001 for all Visa card types.   * 032 : solo   * 033 : visa electron   * 034 : dankort   * 035 : laser   * 036 : carte bleue — formerly Cartes Bancaires   * 037 : carta si   * 038 : pinless debit   * 039 : encoded account   * 040 : uatp   * 041 : household   * 042 : maestro international   * 043 : ge money uk   * 044 : korean cards   * 045 : style   * 046 : jcrew   * 047 : payease china processing ewallet   * 048 : payease china processing bank transfer   * 049 : meijer private label   * 050 : hipercard — supported only by the Comercio Latino processor.   * 051 : aura — supported only by the Comercio Latino processor.   * 052 : redecard   * 054 : elo — supported only by the Comercio Latino processor.   * 055 : capital one private label   * 056 : synchrony private label   * 057 : costco private label   * 060 : mada   * 062 : china union pay   * 063 : falabella private label 

        :return: The type of this Tmsv2customersEmbeddedDefaultPaymentInstrumentCard.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this Tmsv2customersEmbeddedDefaultPaymentInstrumentCard.
        Value that indicates the card type. Valid v2 : v1 - description values:   * 001 : visa   * 002 : mastercard - Eurocard—European regional brand of Mastercard   * 003 : american express   * 004 : discover   * 005 : diners club   * 006 : carte blanche   * 007 : jcb   * 008 : optima   * 011 : twinpay credit   * 012 : twinpay debit   * 013 : walmart   * 014 : enRoute   * 015 : lowes consumer   * 016 : home depot consumer   * 017 : mbna   * 018 : dicks sportswear   * 019 : casual corner   * 020 : sears   * 021 : jal   * 023 : disney   * 024 : maestro uk domestic   * 025 : sams club consumer   * 026 : sams club business   * 028 : bill me later   * 029 : bebe   * 030 : restoration hardware   * 031 : delta online — use this value only for Ingenico ePayments. For other processors, use 001 for all Visa card types.   * 032 : solo   * 033 : visa electron   * 034 : dankort   * 035 : laser   * 036 : carte bleue — formerly Cartes Bancaires   * 037 : carta si   * 038 : pinless debit   * 039 : encoded account   * 040 : uatp   * 041 : household   * 042 : maestro international   * 043 : ge money uk   * 044 : korean cards   * 045 : style   * 046 : jcrew   * 047 : payease china processing ewallet   * 048 : payease china processing bank transfer   * 049 : meijer private label   * 050 : hipercard — supported only by the Comercio Latino processor.   * 051 : aura — supported only by the Comercio Latino processor.   * 052 : redecard   * 054 : elo — supported only by the Comercio Latino processor.   * 055 : capital one private label   * 056 : synchrony private label   * 057 : costco private label   * 060 : mada   * 062 : china union pay   * 063 : falabella private label 

        :param type: The type of this Tmsv2customersEmbeddedDefaultPaymentInstrumentCard.
        :type: str
        """

        self._type = type

    @property
    def issue_number(self):
        """
        Gets the issue_number of this Tmsv2customersEmbeddedDefaultPaymentInstrumentCard.
        Number of times a Maestro (UK Domestic) card has been issued to the account holder. The card might or might not have an issue number. The number can consist of one or two digits, and the first digit might be a zero. When you include this value in your request, include exactly what is printed on the card. A value of 2 is different than a value of 02. Do not include the field, even with a blank value, if the card is not a Maestro (UK Domestic) card.  **Note** The issue number is not required for Maestro (UK Domestic) transactions. 

        :return: The issue_number of this Tmsv2customersEmbeddedDefaultPaymentInstrumentCard.
        :rtype: str
        """
        return self._issue_number

    @issue_number.setter
    def issue_number(self, issue_number):
        """
        Sets the issue_number of this Tmsv2customersEmbeddedDefaultPaymentInstrumentCard.
        Number of times a Maestro (UK Domestic) card has been issued to the account holder. The card might or might not have an issue number. The number can consist of one or two digits, and the first digit might be a zero. When you include this value in your request, include exactly what is printed on the card. A value of 2 is different than a value of 02. Do not include the field, even with a blank value, if the card is not a Maestro (UK Domestic) card.  **Note** The issue number is not required for Maestro (UK Domestic) transactions. 

        :param issue_number: The issue_number of this Tmsv2customersEmbeddedDefaultPaymentInstrumentCard.
        :type: str
        """
        if issue_number is not None and len(issue_number) > 2:
            raise ValueError("Invalid value for `issue_number`, length must be less than or equal to `2`")

        self._issue_number = issue_number

    @property
    def start_month(self):
        """
        Gets the start_month of this Tmsv2customersEmbeddedDefaultPaymentInstrumentCard.
        Month of the start of the Maestro (UK Domestic) card validity period. Do not include the field, even with a blank value, if the card is not a Maestro (UK Domestic) card. `Format: MM`. Valid values: 01 through 12.  **Note** The start date is not required for Maestro (UK Domestic) transactions. 

        :return: The start_month of this Tmsv2customersEmbeddedDefaultPaymentInstrumentCard.
        :rtype: str
        """
        return self._start_month

    @start_month.setter
    def start_month(self, start_month):
        """
        Sets the start_month of this Tmsv2customersEmbeddedDefaultPaymentInstrumentCard.
        Month of the start of the Maestro (UK Domestic) card validity period. Do not include the field, even with a blank value, if the card is not a Maestro (UK Domestic) card. `Format: MM`. Valid values: 01 through 12.  **Note** The start date is not required for Maestro (UK Domestic) transactions. 

        :param start_month: The start_month of this Tmsv2customersEmbeddedDefaultPaymentInstrumentCard.
        :type: str
        """
        if start_month is not None and len(start_month) > 2:
            raise ValueError("Invalid value for `start_month`, length must be less than or equal to `2`")

        self._start_month = start_month

    @property
    def start_year(self):
        """
        Gets the start_year of this Tmsv2customersEmbeddedDefaultPaymentInstrumentCard.
        Year of the start of the Maestro (UK Domestic) card validity period. Do not include the field, even with a blank value, if the card is not a Maestro (UK Domestic) card. `Format: YYYY`.  **Note** The start date is not required for Maestro (UK Domestic) transactions. 

        :return: The start_year of this Tmsv2customersEmbeddedDefaultPaymentInstrumentCard.
        :rtype: str
        """
        return self._start_year

    @start_year.setter
    def start_year(self, start_year):
        """
        Sets the start_year of this Tmsv2customersEmbeddedDefaultPaymentInstrumentCard.
        Year of the start of the Maestro (UK Domestic) card validity period. Do not include the field, even with a blank value, if the card is not a Maestro (UK Domestic) card. `Format: YYYY`.  **Note** The start date is not required for Maestro (UK Domestic) transactions. 

        :param start_year: The start_year of this Tmsv2customersEmbeddedDefaultPaymentInstrumentCard.
        :type: str
        """
        if start_year is not None and len(start_year) > 4:
            raise ValueError("Invalid value for `start_year`, length must be less than or equal to `4`")

        self._start_year = start_year

    @property
    def use_as(self):
        """
        Gets the use_as of this Tmsv2customersEmbeddedDefaultPaymentInstrumentCard.
        'Payment Instrument was created / updated as part of a pinless debit transaction.' 

        :return: The use_as of this Tmsv2customersEmbeddedDefaultPaymentInstrumentCard.
        :rtype: str
        """
        return self._use_as

    @use_as.setter
    def use_as(self, use_as):
        """
        Sets the use_as of this Tmsv2customersEmbeddedDefaultPaymentInstrumentCard.
        'Payment Instrument was created / updated as part of a pinless debit transaction.' 

        :param use_as: The use_as of this Tmsv2customersEmbeddedDefaultPaymentInstrumentCard.
        :type: str
        """

        self._use_as = use_as

    @property
    def tokenized_information(self):
        """
        Gets the tokenized_information of this Tmsv2customersEmbeddedDefaultPaymentInstrumentCard.

        :return: The tokenized_information of this Tmsv2customersEmbeddedDefaultPaymentInstrumentCard.
        :rtype: Tmsv2customersEmbeddedDefaultPaymentInstrumentCardTokenizedInformation
        """
        return self._tokenized_information

    @tokenized_information.setter
    def tokenized_information(self, tokenized_information):
        """
        Sets the tokenized_information of this Tmsv2customersEmbeddedDefaultPaymentInstrumentCard.

        :param tokenized_information: The tokenized_information of this Tmsv2customersEmbeddedDefaultPaymentInstrumentCard.
        :type: Tmsv2customersEmbeddedDefaultPaymentInstrumentCardTokenizedInformation
        """

        self._tokenized_information = tokenized_information

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Tmsv2customersEmbeddedDefaultPaymentInstrumentCard):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class TssV2TransactionsGet200ResponseOrderInformationShipTo(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'first_name': 'str',
        'last_name': 'str',
        'address1': 'str',
        'address2': 'str',
        'locality': 'str',
        'administrative_area': 'str',
        'postal_code': 'str',
        'company': 'str',
        'country': 'str',
        'phone_number': 'str'
    }

    attribute_map = {
        'first_name': 'firstName',
        'last_name': 'lastName',
        'address1': 'address1',
        'address2': 'address2',
        'locality': 'locality',
        'administrative_area': 'administrativeArea',
        'postal_code': 'postalCode',
        'company': 'company',
        'country': 'country',
        'phone_number': 'phoneNumber'
    }

    def __init__(self, first_name=None, last_name=None, address1=None, address2=None, locality=None, administrative_area=None, postal_code=None, company=None, country=None, phone_number=None):
        """
        TssV2TransactionsGet200ResponseOrderInformationShipTo - a model defined in Swagger
        """

        self._first_name = None
        self._last_name = None
        self._address1 = None
        self._address2 = None
        self._locality = None
        self._administrative_area = None
        self._postal_code = None
        self._company = None
        self._country = None
        self._phone_number = None

        if first_name is not None:
          self.first_name = first_name
        if last_name is not None:
          self.last_name = last_name
        if address1 is not None:
          self.address1 = address1
        if address2 is not None:
          self.address2 = address2
        if locality is not None:
          self.locality = locality
        if administrative_area is not None:
          self.administrative_area = administrative_area
        if postal_code is not None:
          self.postal_code = postal_code
        if company is not None:
          self.company = company
        if country is not None:
          self.country = country
        if phone_number is not None:
          self.phone_number = phone_number

    @property
    def first_name(self):
        """
        Gets the first_name of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        First name of the recipient.  #### Litle Maximum length: 25  #### All other processors Maximum length: 60  Optional field. 

        :return: The first_name of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """
        Sets the first_name of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        First name of the recipient.  #### Litle Maximum length: 25  #### All other processors Maximum length: 60  Optional field. 

        :param first_name: The first_name of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        :type: str
        """
        if first_name is not None and len(first_name) > 60:
            raise ValueError("Invalid value for `first_name`, length must be less than or equal to `60`")

        self._first_name = first_name

    @property
    def last_name(self):
        """
        Gets the last_name of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        Last name of the recipient.  #### Litle Maximum length: 25  #### All other processors Maximum length: 60  Optional field. 

        :return: The last_name of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """
        Sets the last_name of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        Last name of the recipient.  #### Litle Maximum length: 25  #### All other processors Maximum length: 60  Optional field. 

        :param last_name: The last_name of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        :type: str
        """
        if last_name is not None and len(last_name) > 60:
            raise ValueError("Invalid value for `last_name`, length must be less than or equal to `60`")

        self._last_name = last_name

    @property
    def address1(self):
        """
        Gets the address1 of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        First line of the shipping address.  Required field for authorization if any shipping address information is included in the request; otherwise, optional.  #### Tax Calculation Optional field for U.S. and Canadian taxes. Not applicable to international and value added taxes. Billing address objects will be used to determine the cardholder’s location when shipTo objects are not present. 

        :return: The address1 of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        :rtype: str
        """
        return self._address1

    @address1.setter
    def address1(self, address1):
        """
        Sets the address1 of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        First line of the shipping address.  Required field for authorization if any shipping address information is included in the request; otherwise, optional.  #### Tax Calculation Optional field for U.S. and Canadian taxes. Not applicable to international and value added taxes. Billing address objects will be used to determine the cardholder’s location when shipTo objects are not present. 

        :param address1: The address1 of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        :type: str
        """
        if address1 is not None and len(address1) > 60:
            raise ValueError("Invalid value for `address1`, length must be less than or equal to `60`")

        self._address1 = address1

    @property
    def address2(self):
        """
        Gets the address2 of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        Second line of the shipping address.  Optional field.  #### Tax Calculation Optional field for U.S. and Canadian taxes. Not applicable to international and value added taxes. Billing address objects will be used to determine the cardholder’s location when shipTo objects are not present. 

        :return: The address2 of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        :rtype: str
        """
        return self._address2

    @address2.setter
    def address2(self, address2):
        """
        Sets the address2 of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        Second line of the shipping address.  Optional field.  #### Tax Calculation Optional field for U.S. and Canadian taxes. Not applicable to international and value added taxes. Billing address objects will be used to determine the cardholder’s location when shipTo objects are not present. 

        :param address2: The address2 of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        :type: str
        """
        if address2 is not None and len(address2) > 60:
            raise ValueError("Invalid value for `address2`, length must be less than or equal to `60`")

        self._address2 = address2

    @property
    def locality(self):
        """
        Gets the locality of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        City of the shipping address.  Required field for authorization if any shipping address information is included in the request and shipping to the U.S. or Canada; otherwise, optional.  #### Tax Calculation Optional field for U.S. and Canadian taxes. Not applicable to international and value added taxes. Billing address objects will be used to determine the cardholder’s location when shipTo objects are not present. 

        :return: The locality of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        :rtype: str
        """
        return self._locality

    @locality.setter
    def locality(self, locality):
        """
        Sets the locality of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        City of the shipping address.  Required field for authorization if any shipping address information is included in the request and shipping to the U.S. or Canada; otherwise, optional.  #### Tax Calculation Optional field for U.S. and Canadian taxes. Not applicable to international and value added taxes. Billing address objects will be used to determine the cardholder’s location when shipTo objects are not present. 

        :param locality: The locality of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        :type: str
        """
        if locality is not None and len(locality) > 50:
            raise ValueError("Invalid value for `locality`, length must be less than or equal to `50`")

        self._locality = locality

    @property
    def administrative_area(self):
        """
        Gets the administrative_area of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        State or province of the billing address. Use the [State, Province, and Territory Codes for the United States and Canada](https://developer.cybersource.com/library/documentation/sbc/quickref/states_and_provinces.pdf).  For Payouts: This field may be sent only for FDC Compass.  ##### CyberSource through VisaNet Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.  **Important** It is your responsibility to determine whether a field is required for the transaction you are requesting.  #### Chase Paymentech Solutions Optional field.  ####  Credit Mutuel-CIC Optional field.  #### OmniPay Direct Optional field.  #### SIX Optional field.  #### TSYS Acquiring Solutions Required when `processingInformation.billPaymentOptions.billPayment=true` and `pointOfSaleInformation.entryMode=keyed`.  #### Worldpay VAP Optional field.  #### All other processors Not used. 

        :return: The administrative_area of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        :rtype: str
        """
        return self._administrative_area

    @administrative_area.setter
    def administrative_area(self, administrative_area):
        """
        Sets the administrative_area of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        State or province of the billing address. Use the [State, Province, and Territory Codes for the United States and Canada](https://developer.cybersource.com/library/documentation/sbc/quickref/states_and_provinces.pdf).  For Payouts: This field may be sent only for FDC Compass.  ##### CyberSource through VisaNet Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.  **Important** It is your responsibility to determine whether a field is required for the transaction you are requesting.  #### Chase Paymentech Solutions Optional field.  ####  Credit Mutuel-CIC Optional field.  #### OmniPay Direct Optional field.  #### SIX Optional field.  #### TSYS Acquiring Solutions Required when `processingInformation.billPaymentOptions.billPayment=true` and `pointOfSaleInformation.entryMode=keyed`.  #### Worldpay VAP Optional field.  #### All other processors Not used. 

        :param administrative_area: The administrative_area of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        :type: str
        """
        if administrative_area is not None and len(administrative_area) > 20:
            raise ValueError("Invalid value for `administrative_area`, length must be less than or equal to `20`")

        self._administrative_area = administrative_area

    @property
    def postal_code(self):
        """
        Gets the postal_code of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        Postal code for the shipping address. The postal code must consist of 5 to 9 digits.  Required field for authorization if any shipping address information is included in the request and shipping to the U.S. or Canada; otherwise, optional.  When the billing country is the U.S., the 9-digit postal code must follow this format: [5 digits][dash][4 digits]  Example 12345-6789  When the billing country is Canada, the 6-digit postal code must follow this format: [alpha][numeric][alpha][space][numeric][alpha][numeric]  Example A1B 2C3  #### American Express Direct Before sending the postal code to the processor, all nonalphanumeric characters are removed and, if the remaining value is longer than nine characters, the value is truncated starting from the right side. #### Tax Calculation Optional field for U.S. and Canadian taxes. Not applicable to international and value added taxes. Billing address objects will be used to determine the cardholder’s location when shipTo objects are not present. 

        :return: The postal_code of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        :rtype: str
        """
        return self._postal_code

    @postal_code.setter
    def postal_code(self, postal_code):
        """
        Sets the postal_code of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        Postal code for the shipping address. The postal code must consist of 5 to 9 digits.  Required field for authorization if any shipping address information is included in the request and shipping to the U.S. or Canada; otherwise, optional.  When the billing country is the U.S., the 9-digit postal code must follow this format: [5 digits][dash][4 digits]  Example 12345-6789  When the billing country is Canada, the 6-digit postal code must follow this format: [alpha][numeric][alpha][space][numeric][alpha][numeric]  Example A1B 2C3  #### American Express Direct Before sending the postal code to the processor, all nonalphanumeric characters are removed and, if the remaining value is longer than nine characters, the value is truncated starting from the right side. #### Tax Calculation Optional field for U.S. and Canadian taxes. Not applicable to international and value added taxes. Billing address objects will be used to determine the cardholder’s location when shipTo objects are not present. 

        :param postal_code: The postal_code of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        :type: str
        """
        if postal_code is not None and len(postal_code) > 10:
            raise ValueError("Invalid value for `postal_code`, length must be less than or equal to `10`")

        self._postal_code = postal_code

    @property
    def company(self):
        """
        Gets the company of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        Name of the customer’s company.  For processor-specific information, see the company_name field in [Credit Card Services Using the SCMP API.](http://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html) 

        :return: The company of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        :rtype: str
        """
        return self._company

    @company.setter
    def company(self, company):
        """
        Sets the company of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        Name of the customer’s company.  For processor-specific information, see the company_name field in [Credit Card Services Using the SCMP API.](http://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html) 

        :param company: The company of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        :type: str
        """
        if company is not None and len(company) > 60:
            raise ValueError("Invalid value for `company`, length must be less than or equal to `60`")

        self._company = company

    @property
    def country(self):
        """
        Gets the country of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        Country of the shipping address. Use the two-character [ISO Standard Country Codes.](http://apps.cybersource.com/library/documentation/sbc/quickref/countries_alpha_list.pdf)  Required field for authorization if any shipping address information is included in the request; otherwise, optional.  #### Tax Calculation Optional field for U.S., Canadian, international tax, and value added taxes. Billing address objects will be used to determine the cardholder’s location when shipTo objects are not present. 

        :return: The country of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """
        Sets the country of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        Country of the shipping address. Use the two-character [ISO Standard Country Codes.](http://apps.cybersource.com/library/documentation/sbc/quickref/countries_alpha_list.pdf)  Required field for authorization if any shipping address information is included in the request; otherwise, optional.  #### Tax Calculation Optional field for U.S., Canadian, international tax, and value added taxes. Billing address objects will be used to determine the cardholder’s location when shipTo objects are not present. 

        :param country: The country of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        :type: str
        """
        if country is not None and len(country) > 2:
            raise ValueError("Invalid value for `country`, length must be less than or equal to `2`")

        self._country = country

    @property
    def phone_number(self):
        """
        Gets the phone_number of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        Phone number associated with the shipping address.

        :return: The phone_number of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """
        Sets the phone_number of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        Phone number associated with the shipping address.

        :param phone_number: The phone_number of this TssV2TransactionsGet200ResponseOrderInformationShipTo.
        :type: str
        """
        if phone_number is not None and len(phone_number) > 15:
            raise ValueError("Invalid value for `phone_number`, length must be less than or equal to `15`")

        self._phone_number = phone_number

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TssV2TransactionsGet200ResponseOrderInformationShipTo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2paymentsOrderInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amount_details': 'Ptsv2paymentsOrderInformationAmountDetails',
        'bill_to': 'Ptsv2paymentsOrderInformationBillTo',
        'ship_to': 'Ptsv2paymentsOrderInformationShipTo',
        'line_items': 'list[Ptsv2paymentsOrderInformationLineItems]',
        'invoice_details': 'Ptsv2paymentsOrderInformationInvoiceDetails',
        'shipping_details': 'Ptsv2paymentsOrderInformationShippingDetails',
        'returns_accepted': 'bool',
        'pre_order': 'str',
        'pre_order_date': 'str',
        'reordered': 'bool',
        'total_offers_count': 'str'
    }

    attribute_map = {
        'amount_details': 'amountDetails',
        'bill_to': 'billTo',
        'ship_to': 'shipTo',
        'line_items': 'lineItems',
        'invoice_details': 'invoiceDetails',
        'shipping_details': 'shippingDetails',
        'returns_accepted': 'returnsAccepted',
        'pre_order': 'preOrder',
        'pre_order_date': 'preOrderDate',
        'reordered': 'reordered',
        'total_offers_count': 'totalOffersCount'
    }

    def __init__(self, amount_details=None, bill_to=None, ship_to=None, line_items=None, invoice_details=None, shipping_details=None, returns_accepted=None, pre_order=None, pre_order_date=None, reordered=None, total_offers_count=None):
        """
        Ptsv2paymentsOrderInformation - a model defined in Swagger
        """

        self._amount_details = None
        self._bill_to = None
        self._ship_to = None
        self._line_items = None
        self._invoice_details = None
        self._shipping_details = None
        self._returns_accepted = None
        self._pre_order = None
        self._pre_order_date = None
        self._reordered = None
        self._total_offers_count = None

        if amount_details is not None:
          self.amount_details = amount_details
        if bill_to is not None:
          self.bill_to = bill_to
        if ship_to is not None:
          self.ship_to = ship_to
        if line_items is not None:
          self.line_items = line_items
        if invoice_details is not None:
          self.invoice_details = invoice_details
        if shipping_details is not None:
          self.shipping_details = shipping_details
        if returns_accepted is not None:
          self.returns_accepted = returns_accepted
        if pre_order is not None:
          self.pre_order = pre_order
        if pre_order_date is not None:
          self.pre_order_date = pre_order_date
        if reordered is not None:
          self.reordered = reordered
        if total_offers_count is not None:
          self.total_offers_count = total_offers_count

    @property
    def amount_details(self):
        """
        Gets the amount_details of this Ptsv2paymentsOrderInformation.

        :return: The amount_details of this Ptsv2paymentsOrderInformation.
        :rtype: Ptsv2paymentsOrderInformationAmountDetails
        """
        return self._amount_details

    @amount_details.setter
    def amount_details(self, amount_details):
        """
        Sets the amount_details of this Ptsv2paymentsOrderInformation.

        :param amount_details: The amount_details of this Ptsv2paymentsOrderInformation.
        :type: Ptsv2paymentsOrderInformationAmountDetails
        """

        self._amount_details = amount_details

    @property
    def bill_to(self):
        """
        Gets the bill_to of this Ptsv2paymentsOrderInformation.

        :return: The bill_to of this Ptsv2paymentsOrderInformation.
        :rtype: Ptsv2paymentsOrderInformationBillTo
        """
        return self._bill_to

    @bill_to.setter
    def bill_to(self, bill_to):
        """
        Sets the bill_to of this Ptsv2paymentsOrderInformation.

        :param bill_to: The bill_to of this Ptsv2paymentsOrderInformation.
        :type: Ptsv2paymentsOrderInformationBillTo
        """

        self._bill_to = bill_to

    @property
    def ship_to(self):
        """
        Gets the ship_to of this Ptsv2paymentsOrderInformation.

        :return: The ship_to of this Ptsv2paymentsOrderInformation.
        :rtype: Ptsv2paymentsOrderInformationShipTo
        """
        return self._ship_to

    @ship_to.setter
    def ship_to(self, ship_to):
        """
        Sets the ship_to of this Ptsv2paymentsOrderInformation.

        :param ship_to: The ship_to of this Ptsv2paymentsOrderInformation.
        :type: Ptsv2paymentsOrderInformationShipTo
        """

        self._ship_to = ship_to

    @property
    def line_items(self):
        """
        Gets the line_items of this Ptsv2paymentsOrderInformation.

        :return: The line_items of this Ptsv2paymentsOrderInformation.
        :rtype: list[Ptsv2paymentsOrderInformationLineItems]
        """
        return self._line_items

    @line_items.setter
    def line_items(self, line_items):
        """
        Sets the line_items of this Ptsv2paymentsOrderInformation.

        :param line_items: The line_items of this Ptsv2paymentsOrderInformation.
        :type: list[Ptsv2paymentsOrderInformationLineItems]
        """

        self._line_items = line_items

    @property
    def invoice_details(self):
        """
        Gets the invoice_details of this Ptsv2paymentsOrderInformation.

        :return: The invoice_details of this Ptsv2paymentsOrderInformation.
        :rtype: Ptsv2paymentsOrderInformationInvoiceDetails
        """
        return self._invoice_details

    @invoice_details.setter
    def invoice_details(self, invoice_details):
        """
        Sets the invoice_details of this Ptsv2paymentsOrderInformation.

        :param invoice_details: The invoice_details of this Ptsv2paymentsOrderInformation.
        :type: Ptsv2paymentsOrderInformationInvoiceDetails
        """

        self._invoice_details = invoice_details

    @property
    def shipping_details(self):
        """
        Gets the shipping_details of this Ptsv2paymentsOrderInformation.

        :return: The shipping_details of this Ptsv2paymentsOrderInformation.
        :rtype: Ptsv2paymentsOrderInformationShippingDetails
        """
        return self._shipping_details

    @shipping_details.setter
    def shipping_details(self, shipping_details):
        """
        Sets the shipping_details of this Ptsv2paymentsOrderInformation.

        :param shipping_details: The shipping_details of this Ptsv2paymentsOrderInformation.
        :type: Ptsv2paymentsOrderInformationShippingDetails
        """

        self._shipping_details = shipping_details

    @property
    def returns_accepted(self):
        """
        Gets the returns_accepted of this Ptsv2paymentsOrderInformation.
        This is only needed when you are requesting both payment and DM service at same time.  Boolean that indicates whether returns are accepted for this order. This field can contain one of the following values: - true: Returns are accepted for this order. - false: Returns are not accepted for this order. 

        :return: The returns_accepted of this Ptsv2paymentsOrderInformation.
        :rtype: bool
        """
        return self._returns_accepted

    @returns_accepted.setter
    def returns_accepted(self, returns_accepted):
        """
        Sets the returns_accepted of this Ptsv2paymentsOrderInformation.
        This is only needed when you are requesting both payment and DM service at same time.  Boolean that indicates whether returns are accepted for this order. This field can contain one of the following values: - true: Returns are accepted for this order. - false: Returns are not accepted for this order. 

        :param returns_accepted: The returns_accepted of this Ptsv2paymentsOrderInformation.
        :type: bool
        """

        self._returns_accepted = returns_accepted

    @property
    def pre_order(self):
        """
        Gets the pre_order of this Ptsv2paymentsOrderInformation.
        Indicates whether cardholder is placing an order with a future availability or release date. This field can contain one of these values: - MERCHANDISE_AVAILABLE: Merchandise available - FUTURE_AVAILABILITY: Future availability 

        :return: The pre_order of this Ptsv2paymentsOrderInformation.
        :rtype: str
        """
        return self._pre_order

    @pre_order.setter
    def pre_order(self, pre_order):
        """
        Sets the pre_order of this Ptsv2paymentsOrderInformation.
        Indicates whether cardholder is placing an order with a future availability or release date. This field can contain one of these values: - MERCHANDISE_AVAILABLE: Merchandise available - FUTURE_AVAILABILITY: Future availability 

        :param pre_order: The pre_order of this Ptsv2paymentsOrderInformation.
        :type: str
        """

        self._pre_order = pre_order

    @property
    def pre_order_date(self):
        """
        Gets the pre_order_date of this Ptsv2paymentsOrderInformation.
        Expected date that a pre-ordered purchase will be available. Format: YYYYMMDD 

        :return: The pre_order_date of this Ptsv2paymentsOrderInformation.
        :rtype: str
        """
        return self._pre_order_date

    @pre_order_date.setter
    def pre_order_date(self, pre_order_date):
        """
        Sets the pre_order_date of this Ptsv2paymentsOrderInformation.
        Expected date that a pre-ordered purchase will be available. Format: YYYYMMDD 

        :param pre_order_date: The pre_order_date of this Ptsv2paymentsOrderInformation.
        :type: str
        """
        if pre_order_date is not None and len(pre_order_date) > 10:
            raise ValueError("Invalid value for `pre_order_date`, length must be less than or equal to `10`")

        self._pre_order_date = pre_order_date

    @property
    def reordered(self):
        """
        Gets the reordered of this Ptsv2paymentsOrderInformation.
        Indicates whether the cardholder is reordering previously purchased merchandise. This field can contain one of these values: - false: First time ordered - true: Reordered 

        :return: The reordered of this Ptsv2paymentsOrderInformation.
        :rtype: bool
        """
        return self._reordered

    @reordered.setter
    def reordered(self, reordered):
        """
        Sets the reordered of this Ptsv2paymentsOrderInformation.
        Indicates whether the cardholder is reordering previously purchased merchandise. This field can contain one of these values: - false: First time ordered - true: Reordered 

        :param reordered: The reordered of this Ptsv2paymentsOrderInformation.
        :type: bool
        """

        self._reordered = reordered

    @property
    def total_offers_count(self):
        """
        Gets the total_offers_count of this Ptsv2paymentsOrderInformation.
        Total number of articles/items in the order as a numeric decimal count. Possible values: 00 - 99 

        :return: The total_offers_count of this Ptsv2paymentsOrderInformation.
        :rtype: str
        """
        return self._total_offers_count

    @total_offers_count.setter
    def total_offers_count(self, total_offers_count):
        """
        Sets the total_offers_count of this Ptsv2paymentsOrderInformation.
        Total number of articles/items in the order as a numeric decimal count. Possible values: 00 - 99 

        :param total_offers_count: The total_offers_count of this Ptsv2paymentsOrderInformation.
        :type: str
        """
        if total_offers_count is not None and len(total_offers_count) > 2:
            raise ValueError("Invalid value for `total_offers_count`, length must be less than or equal to `2`")

        self._total_offers_count = total_offers_count

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2paymentsOrderInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2paymentsMerchantInformationServiceFeeDescriptor(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'contact': 'str',
        'state': 'str'
    }

    attribute_map = {
        'name': 'name',
        'contact': 'contact',
        'state': 'state'
    }

    def __init__(self, name=None, contact=None, state=None):
        """
        Ptsv2paymentsMerchantInformationServiceFeeDescriptor - a model defined in Swagger
        """

        self._name = None
        self._contact = None
        self._state = None

        if name is not None:
          self.name = name
        if contact is not None:
          self.contact = contact
        if state is not None:
          self.state = state

    @property
    def name(self):
        """
        Gets the name of this Ptsv2paymentsMerchantInformationServiceFeeDescriptor.
        Name of the service provider that is collecting the service fee. The service provider name must consist of 3, 7, or 12 characters followed by an asterisk (*). This value must also include the words “Service Fee.”  When you include more than one consecutive space, extra spaces are removed. Use one of the following formats for this value: - <3-character name>*Service Fee - <7-character name>*Service Fee - <12-character name>*Service Fee  When payments are made in installments, this value must also include installment information such as “1 of 5” or “3 of 7.” For installment payments, use one of the following formats for this value: - <3-character name>*Service Fee*<N> of <M> - <7-character name>*Service Fee*<N> of <M> - <12-character name>*Service Fee*<N> of <M>  where <N> is the payment number and <M> is the total number of payments.  When you do not include this value in your request, CyberSource uses the value that is in your CyberSource account.  This value might be displayed on the cardholder’s statement. 

        :return: The name of this Ptsv2paymentsMerchantInformationServiceFeeDescriptor.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Ptsv2paymentsMerchantInformationServiceFeeDescriptor.
        Name of the service provider that is collecting the service fee. The service provider name must consist of 3, 7, or 12 characters followed by an asterisk (*). This value must also include the words “Service Fee.”  When you include more than one consecutive space, extra spaces are removed. Use one of the following formats for this value: - <3-character name>*Service Fee - <7-character name>*Service Fee - <12-character name>*Service Fee  When payments are made in installments, this value must also include installment information such as “1 of 5” or “3 of 7.” For installment payments, use one of the following formats for this value: - <3-character name>*Service Fee*<N> of <M> - <7-character name>*Service Fee*<N> of <M> - <12-character name>*Service Fee*<N> of <M>  where <N> is the payment number and <M> is the total number of payments.  When you do not include this value in your request, CyberSource uses the value that is in your CyberSource account.  This value might be displayed on the cardholder’s statement. 

        :param name: The name of this Ptsv2paymentsMerchantInformationServiceFeeDescriptor.
        :type: str
        """
        if name is not None and len(name) > 22:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `22`")

        self._name = name

    @property
    def contact(self):
        """
        Gets the contact of this Ptsv2paymentsMerchantInformationServiceFeeDescriptor.
        Contact information for the service provider that is collecting the service fee. when you include more than one consecutive space, extra spaces are removed.  When you do not include this value in your request, CyberSource uses the value that is in your CyberSource account.  This value might be displayed on the cardholder’s statement. 

        :return: The contact of this Ptsv2paymentsMerchantInformationServiceFeeDescriptor.
        :rtype: str
        """
        return self._contact

    @contact.setter
    def contact(self, contact):
        """
        Sets the contact of this Ptsv2paymentsMerchantInformationServiceFeeDescriptor.
        Contact information for the service provider that is collecting the service fee. when you include more than one consecutive space, extra spaces are removed.  When you do not include this value in your request, CyberSource uses the value that is in your CyberSource account.  This value might be displayed on the cardholder’s statement. 

        :param contact: The contact of this Ptsv2paymentsMerchantInformationServiceFeeDescriptor.
        :type: str
        """
        if contact is not None and len(contact) > 11:
            raise ValueError("Invalid value for `contact`, length must be less than or equal to `11`")

        self._contact = contact

    @property
    def state(self):
        """
        Gets the state of this Ptsv2paymentsMerchantInformationServiceFeeDescriptor.
        State or territory in which the service provider is located.  When you do not include this value in your request, CyberSource uses the value that is in your CyberSource account.  This value might be displayed on the cardholder’s statement. 

        :return: The state of this Ptsv2paymentsMerchantInformationServiceFeeDescriptor.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this Ptsv2paymentsMerchantInformationServiceFeeDescriptor.
        State or territory in which the service provider is located.  When you do not include this value in your request, CyberSource uses the value that is in your CyberSource account.  This value might be displayed on the cardholder’s statement. 

        :param state: The state of this Ptsv2paymentsMerchantInformationServiceFeeDescriptor.
        :type: str
        """
        if state is not None and len(state) > 20:
            raise ValueError("Invalid value for `state`, length must be less than or equal to `20`")

        self._state = state

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2paymentsMerchantInformationServiceFeeDescriptor):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'currency_code': 'str',
        'payment_sub_type_description': 'str',
        'start_time': 'datetime',
        'end_time': 'datetime',
        'sales_count': 'int',
        'sales_amount': 'str',
        'credit_count': 'int',
        'credit_amount': 'str',
        'account_name': 'str',
        'account_id': 'str',
        'merchant_id': 'str',
        'merchant_name': 'str'
    }

    attribute_map = {
        'currency_code': 'currencyCode',
        'payment_sub_type_description': 'paymentSubTypeDescription',
        'start_time': 'startTime',
        'end_time': 'endTime',
        'sales_count': 'salesCount',
        'sales_amount': 'salesAmount',
        'credit_count': 'creditCount',
        'credit_amount': 'creditAmount',
        'account_name': 'accountName',
        'account_id': 'accountId',
        'merchant_id': 'merchantId',
        'merchant_name': 'merchantName'
    }

    def __init__(self, currency_code=None, payment_sub_type_description=None, start_time=None, end_time=None, sales_count=None, sales_amount=None, credit_count=None, credit_amount=None, account_name=None, account_id=None, merchant_id=None, merchant_name=None):
        """
        ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries - a model defined in Swagger
        """

        self._currency_code = None
        self._payment_sub_type_description = None
        self._start_time = None
        self._end_time = None
        self._sales_count = None
        self._sales_amount = None
        self._credit_count = None
        self._credit_amount = None
        self._account_name = None
        self._account_id = None
        self._merchant_id = None
        self._merchant_name = None

        if currency_code is not None:
          self.currency_code = currency_code
        if payment_sub_type_description is not None:
          self.payment_sub_type_description = payment_sub_type_description
        if start_time is not None:
          self.start_time = start_time
        if end_time is not None:
          self.end_time = end_time
        if sales_count is not None:
          self.sales_count = sales_count
        if sales_amount is not None:
          self.sales_amount = sales_amount
        if credit_count is not None:
          self.credit_count = credit_count
        if credit_amount is not None:
          self.credit_amount = credit_amount
        if account_name is not None:
          self.account_name = account_name
        if account_id is not None:
          self.account_id = account_id
        if merchant_id is not None:
          self.merchant_id = merchant_id
        if merchant_name is not None:
          self.merchant_name = merchant_name

    @property
    def currency_code(self):
        """
        Gets the currency_code of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.

        :return: The currency_code of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """
        Sets the currency_code of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.

        :param currency_code: The currency_code of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.
        :type: str
        """

        self._currency_code = currency_code

    @property
    def payment_sub_type_description(self):
        """
        Gets the payment_sub_type_description of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.

        :return: The payment_sub_type_description of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.
        :rtype: str
        """
        return self._payment_sub_type_description

    @payment_sub_type_description.setter
    def payment_sub_type_description(self, payment_sub_type_description):
        """
        Sets the payment_sub_type_description of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.

        :param payment_sub_type_description: The payment_sub_type_description of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.
        :type: str
        """

        self._payment_sub_type_description = payment_sub_type_description

    @property
    def start_time(self):
        """
        Gets the start_time of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.

        :return: The start_time of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """
        Sets the start_time of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.

        :param start_time: The start_time of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.
        :type: datetime
        """

        self._start_time = start_time

    @property
    def end_time(self):
        """
        Gets the end_time of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.

        :return: The end_time of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """
        Sets the end_time of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.

        :param end_time: The end_time of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.
        :type: datetime
        """

        self._end_time = end_time

    @property
    def sales_count(self):
        """
        Gets the sales_count of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.

        :return: The sales_count of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.
        :rtype: int
        """
        return self._sales_count

    @sales_count.setter
    def sales_count(self, sales_count):
        """
        Sets the sales_count of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.

        :param sales_count: The sales_count of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.
        :type: int
        """

        self._sales_count = sales_count

    @property
    def sales_amount(self):
        """
        Gets the sales_amount of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.

        :return: The sales_amount of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.
        :rtype: str
        """
        return self._sales_amount

    @sales_amount.setter
    def sales_amount(self, sales_amount):
        """
        Sets the sales_amount of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.

        :param sales_amount: The sales_amount of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.
        :type: str
        """

        self._sales_amount = sales_amount

    @property
    def credit_count(self):
        """
        Gets the credit_count of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.

        :return: The credit_count of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.
        :rtype: int
        """
        return self._credit_count

    @credit_count.setter
    def credit_count(self, credit_count):
        """
        Sets the credit_count of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.

        :param credit_count: The credit_count of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.
        :type: int
        """

        self._credit_count = credit_count

    @property
    def credit_amount(self):
        """
        Gets the credit_amount of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.

        :return: The credit_amount of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.
        :rtype: str
        """
        return self._credit_amount

    @credit_amount.setter
    def credit_amount(self, credit_amount):
        """
        Sets the credit_amount of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.

        :param credit_amount: The credit_amount of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.
        :type: str
        """

        self._credit_amount = credit_amount

    @property
    def account_name(self):
        """
        Gets the account_name of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.

        :return: The account_name of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.
        :rtype: str
        """
        return self._account_name

    @account_name.setter
    def account_name(self, account_name):
        """
        Sets the account_name of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.

        :param account_name: The account_name of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.
        :type: str
        """

        self._account_name = account_name

    @property
    def account_id(self):
        """
        Gets the account_id of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.

        :return: The account_id of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """
        Sets the account_id of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.

        :param account_id: The account_id of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.
        :type: str
        """

        self._account_id = account_id

    @property
    def merchant_id(self):
        """
        Gets the merchant_id of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.

        :return: The merchant_id of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.
        :rtype: str
        """
        return self._merchant_id

    @merchant_id.setter
    def merchant_id(self, merchant_id):
        """
        Sets the merchant_id of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.

        :param merchant_id: The merchant_id of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.
        :type: str
        """

        self._merchant_id = merchant_id

    @property
    def merchant_name(self):
        """
        Gets the merchant_name of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.

        :return: The merchant_name of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.
        :rtype: str
        """
        return self._merchant_name

    @merchant_name.setter
    def merchant_name(self, merchant_name):
        """
        Sets the merchant_name of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.

        :param merchant_name: The merchant_name of this ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries.
        :type: str
        """

        self._merchant_name = merchant_name

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2creditsProcessingInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'commerce_indicator': 'str',
        'processor_id': 'str',
        'payment_solution': 'str',
        'reconciliation_id': 'str',
        'link_id': 'str',
        'report_group': 'str',
        'visa_checkout_id': 'str',
        'purchase_level': 'str',
        'industry_data_type': 'str',
        'wallet_type': 'str',
        'national_net_domestic_data': 'str',
        'network_routing_order': 'str',
        'recurring_options': 'Ptsv2paymentsidrefundsProcessingInformationRecurringOptions',
        'bank_transfer_options': 'Ptsv2creditsProcessingInformationBankTransferOptions',
        'purchase_options': 'Ptsv2creditsProcessingInformationPurchaseOptions',
        'electronic_benefits_transfer': 'Ptsv2creditsProcessingInformationElectronicBenefitsTransfer',
        'loan_options': 'Ptsv2paymentsProcessingInformationLoanOptions',
        'japan_payment_options': 'Ptsv2creditsProcessingInformationJapanPaymentOptions'
    }

    attribute_map = {
        'commerce_indicator': 'commerceIndicator',
        'processor_id': 'processorId',
        'payment_solution': 'paymentSolution',
        'reconciliation_id': 'reconciliationId',
        'link_id': 'linkId',
        'report_group': 'reportGroup',
        'visa_checkout_id': 'visaCheckoutId',
        'purchase_level': 'purchaseLevel',
        'industry_data_type': 'industryDataType',
        'wallet_type': 'walletType',
        'national_net_domestic_data': 'nationalNetDomesticData',
        'network_routing_order': 'networkRoutingOrder',
        'recurring_options': 'recurringOptions',
        'bank_transfer_options': 'bankTransferOptions',
        'purchase_options': 'purchaseOptions',
        'electronic_benefits_transfer': 'electronicBenefitsTransfer',
        'loan_options': 'loanOptions',
        'japan_payment_options': 'japanPaymentOptions'
    }

    def __init__(self, commerce_indicator=None, processor_id=None, payment_solution=None, reconciliation_id=None, link_id=None, report_group=None, visa_checkout_id=None, purchase_level=None, industry_data_type=None, wallet_type=None, national_net_domestic_data=None, network_routing_order=None, recurring_options=None, bank_transfer_options=None, purchase_options=None, electronic_benefits_transfer=None, loan_options=None, japan_payment_options=None):
        """
        Ptsv2creditsProcessingInformation - a model defined in Swagger
        """

        self._commerce_indicator = None
        self._processor_id = None
        self._payment_solution = None
        self._reconciliation_id = None
        self._link_id = None
        self._report_group = None
        self._visa_checkout_id = None
        self._purchase_level = None
        self._industry_data_type = None
        self._wallet_type = None
        self._national_net_domestic_data = None
        self._network_routing_order = None
        self._recurring_options = None
        self._bank_transfer_options = None
        self._purchase_options = None
        self._electronic_benefits_transfer = None
        self._loan_options = None
        self._japan_payment_options = None

        if commerce_indicator is not None:
          self.commerce_indicator = commerce_indicator
        if processor_id is not None:
          self.processor_id = processor_id
        if payment_solution is not None:
          self.payment_solution = payment_solution
        if reconciliation_id is not None:
          self.reconciliation_id = reconciliation_id
        if link_id is not None:
          self.link_id = link_id
        if report_group is not None:
          self.report_group = report_group
        if visa_checkout_id is not None:
          self.visa_checkout_id = visa_checkout_id
        if purchase_level is not None:
          self.purchase_level = purchase_level
        if industry_data_type is not None:
          self.industry_data_type = industry_data_type
        if wallet_type is not None:
          self.wallet_type = wallet_type
        if national_net_domestic_data is not None:
          self.national_net_domestic_data = national_net_domestic_data
        if network_routing_order is not None:
          self.network_routing_order = network_routing_order
        if recurring_options is not None:
          self.recurring_options = recurring_options
        if bank_transfer_options is not None:
          self.bank_transfer_options = bank_transfer_options
        if purchase_options is not None:
          self.purchase_options = purchase_options
        if electronic_benefits_transfer is not None:
          self.electronic_benefits_transfer = electronic_benefits_transfer
        if loan_options is not None:
          self.loan_options = loan_options
        if japan_payment_options is not None:
          self.japan_payment_options = japan_payment_options

    @property
    def commerce_indicator(self):
        """
        Gets the commerce_indicator of this Ptsv2creditsProcessingInformation.
        Type of transaction. Some payment card companies use this information when determining discount rates.  #### Used by **Authorization** Required payer authentication transactions; otherwise, optional. **Credit** Required for standalone credits on Chase Paymentech solutions; otherwise, optional. Only `internet`, `moto`, `recurring`, and `recurring_internet` are valid values.  #### Ingenico ePayments When you omit this field for Ingenico ePayments, the processor uses the default transaction type they have on file for you instead of the default value (listed in Appendix I, \"Commerce Indicators,\" on page 441.)  #### Payer Authentication Transactions For the possible values and requirements, see \"Payer Authentication,\" page 195.  #### Other Types of Transactions See Appendix I, \"Commerce Indicators,\" on page 441.  #### Card Present You must set this field to `retail`. This field is required for a card-present transaction. 

        :return: The commerce_indicator of this Ptsv2creditsProcessingInformation.
        :rtype: str
        """
        return self._commerce_indicator

    @commerce_indicator.setter
    def commerce_indicator(self, commerce_indicator):
        """
        Sets the commerce_indicator of this Ptsv2creditsProcessingInformation.
        Type of transaction. Some payment card companies use this information when determining discount rates.  #### Used by **Authorization** Required payer authentication transactions; otherwise, optional. **Credit** Required for standalone credits on Chase Paymentech solutions; otherwise, optional. Only `internet`, `moto`, `recurring`, and `recurring_internet` are valid values.  #### Ingenico ePayments When you omit this field for Ingenico ePayments, the processor uses the default transaction type they have on file for you instead of the default value (listed in Appendix I, \"Commerce Indicators,\" on page 441.)  #### Payer Authentication Transactions For the possible values and requirements, see \"Payer Authentication,\" page 195.  #### Other Types of Transactions See Appendix I, \"Commerce Indicators,\" on page 441.  #### Card Present You must set this field to `retail`. This field is required for a card-present transaction. 

        :param commerce_indicator: The commerce_indicator of this Ptsv2creditsProcessingInformation.
        :type: str
        """
        if commerce_indicator is not None and len(commerce_indicator) > 20:
            raise ValueError("Invalid value for `commerce_indicator`, length must be less than or equal to `20`")

        self._commerce_indicator = commerce_indicator

    @property
    def processor_id(self):
        """
        Gets the processor_id of this Ptsv2creditsProcessingInformation.
        Value that identifies the processor/acquirer to use for the transaction. This value is supported only for **CyberSource through VisaNet**.  Contact CyberSource Customer Support to get the value for this field. 

        :return: The processor_id of this Ptsv2creditsProcessingInformation.
        :rtype: str
        """
        return self._processor_id

    @processor_id.setter
    def processor_id(self, processor_id):
        """
        Sets the processor_id of this Ptsv2creditsProcessingInformation.
        Value that identifies the processor/acquirer to use for the transaction. This value is supported only for **CyberSource through VisaNet**.  Contact CyberSource Customer Support to get the value for this field. 

        :param processor_id: The processor_id of this Ptsv2creditsProcessingInformation.
        :type: str
        """
        if processor_id is not None and len(processor_id) > 3:
            raise ValueError("Invalid value for `processor_id`, length must be less than or equal to `3`")

        self._processor_id = processor_id

    @property
    def payment_solution(self):
        """
        Gets the payment_solution of this Ptsv2creditsProcessingInformation.
        Type of digital payment solution for the transaction. Possible Values:   - `visacheckout`: Visa Checkout. This value is required for Visa Checkout transactions. For details, see `payment_solution` field description in [Visa Checkout Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/VCO_SCMP_API/html/)  - `001`: Apple Pay.  - `004`: Cybersource In-App Solution.  - `005`: Masterpass. This value is required for Masterpass transactions on OmniPay Direct. For details, see \"Masterpass\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  - `006`: Android Pay.  - `007`: Chase Pay.  - `008`: Samsung Pay.  - `012`: Google Pay. 

        :return: The payment_solution of this Ptsv2creditsProcessingInformation.
        :rtype: str
        """
        return self._payment_solution

    @payment_solution.setter
    def payment_solution(self, payment_solution):
        """
        Sets the payment_solution of this Ptsv2creditsProcessingInformation.
        Type of digital payment solution for the transaction. Possible Values:   - `visacheckout`: Visa Checkout. This value is required for Visa Checkout transactions. For details, see `payment_solution` field description in [Visa Checkout Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/VCO_SCMP_API/html/)  - `001`: Apple Pay.  - `004`: Cybersource In-App Solution.  - `005`: Masterpass. This value is required for Masterpass transactions on OmniPay Direct. For details, see \"Masterpass\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  - `006`: Android Pay.  - `007`: Chase Pay.  - `008`: Samsung Pay.  - `012`: Google Pay. 

        :param payment_solution: The payment_solution of this Ptsv2creditsProcessingInformation.
        :type: str
        """
        if payment_solution is not None and len(payment_solution) > 12:
            raise ValueError("Invalid value for `payment_solution`, length must be less than or equal to `12`")

        self._payment_solution = payment_solution

    @property
    def reconciliation_id(self):
        """
        Gets the reconciliation_id of this Ptsv2creditsProcessingInformation.
        Please check with Cybersource customer support to see if your merchant account is configured correctly so you can include this field in your request. * For Payouts: max length for FDCCompass is String (22). 

        :return: The reconciliation_id of this Ptsv2creditsProcessingInformation.
        :rtype: str
        """
        return self._reconciliation_id

    @reconciliation_id.setter
    def reconciliation_id(self, reconciliation_id):
        """
        Sets the reconciliation_id of this Ptsv2creditsProcessingInformation.
        Please check with Cybersource customer support to see if your merchant account is configured correctly so you can include this field in your request. * For Payouts: max length for FDCCompass is String (22). 

        :param reconciliation_id: The reconciliation_id of this Ptsv2creditsProcessingInformation.
        :type: str
        """
        if reconciliation_id is not None and len(reconciliation_id) > 60:
            raise ValueError("Invalid value for `reconciliation_id`, length must be less than or equal to `60`")

        self._reconciliation_id = reconciliation_id

    @property
    def link_id(self):
        """
        Gets the link_id of this Ptsv2creditsProcessingInformation.
        Value that links the current authorization request to the original authorization request. Set this value to the ID that was returned in the reply message from the original authorization request.  This value is used for:  - Partial authorizations - Split shipments  For details, see `link_to_request` field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :return: The link_id of this Ptsv2creditsProcessingInformation.
        :rtype: str
        """
        return self._link_id

    @link_id.setter
    def link_id(self, link_id):
        """
        Sets the link_id of this Ptsv2creditsProcessingInformation.
        Value that links the current authorization request to the original authorization request. Set this value to the ID that was returned in the reply message from the original authorization request.  This value is used for:  - Partial authorizations - Split shipments  For details, see `link_to_request` field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :param link_id: The link_id of this Ptsv2creditsProcessingInformation.
        :type: str
        """
        if link_id is not None and len(link_id) > 26:
            raise ValueError("Invalid value for `link_id`, length must be less than or equal to `26`")

        self._link_id = link_id

    @property
    def report_group(self):
        """
        Gets the report_group of this Ptsv2creditsProcessingInformation.
        Attribute that lets you define custom grouping for your processor reports. This field is supported only for **Worldpay VAP**.  For details, see `report_group` field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :return: The report_group of this Ptsv2creditsProcessingInformation.
        :rtype: str
        """
        return self._report_group

    @report_group.setter
    def report_group(self, report_group):
        """
        Sets the report_group of this Ptsv2creditsProcessingInformation.
        Attribute that lets you define custom grouping for your processor reports. This field is supported only for **Worldpay VAP**.  For details, see `report_group` field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :param report_group: The report_group of this Ptsv2creditsProcessingInformation.
        :type: str
        """
        if report_group is not None and len(report_group) > 25:
            raise ValueError("Invalid value for `report_group`, length must be less than or equal to `25`")

        self._report_group = report_group

    @property
    def visa_checkout_id(self):
        """
        Gets the visa_checkout_id of this Ptsv2creditsProcessingInformation.
        Identifier for the **Visa Checkout** order. Visa Checkout provides a unique order ID for every transaction in the Visa Checkout **callID** field. 

        :return: The visa_checkout_id of this Ptsv2creditsProcessingInformation.
        :rtype: str
        """
        return self._visa_checkout_id

    @visa_checkout_id.setter
    def visa_checkout_id(self, visa_checkout_id):
        """
        Sets the visa_checkout_id of this Ptsv2creditsProcessingInformation.
        Identifier for the **Visa Checkout** order. Visa Checkout provides a unique order ID for every transaction in the Visa Checkout **callID** field. 

        :param visa_checkout_id: The visa_checkout_id of this Ptsv2creditsProcessingInformation.
        :type: str
        """
        if visa_checkout_id is not None and len(visa_checkout_id) > 48:
            raise ValueError("Invalid value for `visa_checkout_id`, length must be less than or equal to `48`")

        self._visa_checkout_id = visa_checkout_id

    @property
    def purchase_level(self):
        """
        Gets the purchase_level of this Ptsv2creditsProcessingInformation.
        Set this field to 3 to indicate that the request includes Level III data.

        :return: The purchase_level of this Ptsv2creditsProcessingInformation.
        :rtype: str
        """
        return self._purchase_level

    @purchase_level.setter
    def purchase_level(self, purchase_level):
        """
        Sets the purchase_level of this Ptsv2creditsProcessingInformation.
        Set this field to 3 to indicate that the request includes Level III data.

        :param purchase_level: The purchase_level of this Ptsv2creditsProcessingInformation.
        :type: str
        """
        if purchase_level is not None and len(purchase_level) > 1:
            raise ValueError("Invalid value for `purchase_level`, length must be less than or equal to `1`")

        self._purchase_level = purchase_level

    @property
    def industry_data_type(self):
        """
        Gets the industry_data_type of this Ptsv2creditsProcessingInformation.
        Indicates that the transaction includes industry-specific data.  Possible Values: - `airline` - `restaurant` - `lodging` - `auto_rental` - `transit` - `healthcare_medical` - `healthcare_transit` - `transit`  #### Card Present, Airlines and Auto Rental You must set this field to `airline` in order for airline data to be sent to the processor. For example, if this field is not set to `airline` or is not included in the request, no airline data is sent to the processor.  You must set this field to `restaurant` in order for restaurant data to be sent to the processor. When this field is not set to `restaurant` or is not included in the request, no restaurant data is sent to the processor.  You must set this field to `auto_rental` in order for auto rental data to be sent to the processor. For example, if this field is not set to `auto_rental` or is not included in the request, no auto rental data is sent to the processor.  Restaurant data is supported only on CyberSource through VisaNet. 

        :return: The industry_data_type of this Ptsv2creditsProcessingInformation.
        :rtype: str
        """
        return self._industry_data_type

    @industry_data_type.setter
    def industry_data_type(self, industry_data_type):
        """
        Sets the industry_data_type of this Ptsv2creditsProcessingInformation.
        Indicates that the transaction includes industry-specific data.  Possible Values: - `airline` - `restaurant` - `lodging` - `auto_rental` - `transit` - `healthcare_medical` - `healthcare_transit` - `transit`  #### Card Present, Airlines and Auto Rental You must set this field to `airline` in order for airline data to be sent to the processor. For example, if this field is not set to `airline` or is not included in the request, no airline data is sent to the processor.  You must set this field to `restaurant` in order for restaurant data to be sent to the processor. When this field is not set to `restaurant` or is not included in the request, no restaurant data is sent to the processor.  You must set this field to `auto_rental` in order for auto rental data to be sent to the processor. For example, if this field is not set to `auto_rental` or is not included in the request, no auto rental data is sent to the processor.  Restaurant data is supported only on CyberSource through VisaNet. 

        :param industry_data_type: The industry_data_type of this Ptsv2creditsProcessingInformation.
        :type: str
        """
        if industry_data_type is not None and len(industry_data_type) > 20:
            raise ValueError("Invalid value for `industry_data_type`, length must be less than or equal to `20`")

        self._industry_data_type = industry_data_type

    @property
    def wallet_type(self):
        """
        Gets the wallet_type of this Ptsv2creditsProcessingInformation.
        This field carries the wallet type in authorization requests and credit requests. Possible value are: - `101`: Masterpass remote payment. The customer created the wallet by manually interacting with a customer-controlled device such as a computer, tablet, or phone. This value is supported only for Masterpass transactions on Chase Paymentech Solutions and CyberSource through VisaNet. - `102`: Masterpass remote near field communication (NFC) payment. The customer created the wallet by tapping a PayPass card or customer-controlled device at a contactless card reader. This value is supported only for card-present Masterpass transactions on CyberSource through VisaNet. - `103`: Masterpass Apple Pay payment. The payment was made with a combination of Masterpass and Apple Pay. This value is supported only for Masterpass Apple Pay transactions on CyberSource through VisaNet. - `216`: Masterpass Google Pay payment. The payment was made with a combination of Masterpass and Google Pay. This value is supported only for Masterpass Google Pay transactions on CyberSource through VisaNet. - `217`: Masterpass Samsung Pay payment. The payment was made with a combination of Masterpass and Samsung Pay. This value is supported only for Masterpass Samsung Pay transactions on CyberSource through VisaNet. - `SDW`: Staged digital wallet. An issuer or operator created the wallet. This value is supported only for Masterpass transactions on Chase Paymentech Solutions. - `VCIND`: Visa Checkout payment. This value is supported only on CyberSource through VisaNet, FDC Compass, FDC Nashville Global, FDI Australia, and TSYS Acquiring Solutions. See Getting Started with Visa Checkout. For Visa Checkout transactions, the way CyberSource processes the value for this field depends on the processor. See the Visa Checkout section below. For all other values, this field is a passthrough; therefore, CyberSource does not verify the value or modify it in any way before sending it to the processor. Masterpass (101, 102, 103, 216, and 217): The Masterpass platform generates the wallet type value and passes it to you along with the customer’s checkout information.  Visa Checkout: This field is optional for Visa Checkout authorizations on FDI Australia. For all other processors, this field is required for Visa Checkout authorizations. For Visa Checkout transactions on the following processors, CyberSource sends the value that the processor expects for this field:FDC Compass,FDC Nashville Global,FDI Australia,TSYS Acquiring Solutions For all other processors, this field is a passthrough; therefore, CyberSource does not verify the value or modify it in any way before sending it to the processor. For incremental authorizations, this field is supported only for Mastercard and the supported values are 101 and 102. Payment card companies can introduce new values without notice. Your order management system should be able to process new values without problems.  CyberSource through VisaNet When the value for this field is 101, 102, 103, 216, or 217, it corresponds to the following data in the TC 33 capture file5: Record: CP01 TCR6, Position: 88-90,  Field: Mastercard Wallet Identifier. When the value for this field is VCIND, it corresponds to the following data in the TC 33 capture file5: Record: CP01 TCR8, Position: 72-76, Field: Agent Unique ID. 

        :return: The wallet_type of this Ptsv2creditsProcessingInformation.
        :rtype: str
        """
        return self._wallet_type

    @wallet_type.setter
    def wallet_type(self, wallet_type):
        """
        Sets the wallet_type of this Ptsv2creditsProcessingInformation.
        This field carries the wallet type in authorization requests and credit requests. Possible value are: - `101`: Masterpass remote payment. The customer created the wallet by manually interacting with a customer-controlled device such as a computer, tablet, or phone. This value is supported only for Masterpass transactions on Chase Paymentech Solutions and CyberSource through VisaNet. - `102`: Masterpass remote near field communication (NFC) payment. The customer created the wallet by tapping a PayPass card or customer-controlled device at a contactless card reader. This value is supported only for card-present Masterpass transactions on CyberSource through VisaNet. - `103`: Masterpass Apple Pay payment. The payment was made with a combination of Masterpass and Apple Pay. This value is supported only for Masterpass Apple Pay transactions on CyberSource through VisaNet. - `216`: Masterpass Google Pay payment. The payment was made with a combination of Masterpass and Google Pay. This value is supported only for Masterpass Google Pay transactions on CyberSource through VisaNet. - `217`: Masterpass Samsung Pay payment. The payment was made with a combination of Masterpass and Samsung Pay. This value is supported only for Masterpass Samsung Pay transactions on CyberSource through VisaNet. - `SDW`: Staged digital wallet. An issuer or operator created the wallet. This value is supported only for Masterpass transactions on Chase Paymentech Solutions. - `VCIND`: Visa Checkout payment. This value is supported only on CyberSource through VisaNet, FDC Compass, FDC Nashville Global, FDI Australia, and TSYS Acquiring Solutions. See Getting Started with Visa Checkout. For Visa Checkout transactions, the way CyberSource processes the value for this field depends on the processor. See the Visa Checkout section below. For all other values, this field is a passthrough; therefore, CyberSource does not verify the value or modify it in any way before sending it to the processor. Masterpass (101, 102, 103, 216, and 217): The Masterpass platform generates the wallet type value and passes it to you along with the customer’s checkout information.  Visa Checkout: This field is optional for Visa Checkout authorizations on FDI Australia. For all other processors, this field is required for Visa Checkout authorizations. For Visa Checkout transactions on the following processors, CyberSource sends the value that the processor expects for this field:FDC Compass,FDC Nashville Global,FDI Australia,TSYS Acquiring Solutions For all other processors, this field is a passthrough; therefore, CyberSource does not verify the value or modify it in any way before sending it to the processor. For incremental authorizations, this field is supported only for Mastercard and the supported values are 101 and 102. Payment card companies can introduce new values without notice. Your order management system should be able to process new values without problems.  CyberSource through VisaNet When the value for this field is 101, 102, 103, 216, or 217, it corresponds to the following data in the TC 33 capture file5: Record: CP01 TCR6, Position: 88-90,  Field: Mastercard Wallet Identifier. When the value for this field is VCIND, it corresponds to the following data in the TC 33 capture file5: Record: CP01 TCR8, Position: 72-76, Field: Agent Unique ID. 

        :param wallet_type: The wallet_type of this Ptsv2creditsProcessingInformation.
        :type: str
        """
        if wallet_type is not None and len(wallet_type) > 5:
            raise ValueError("Invalid value for `wallet_type`, length must be less than or equal to `5`")

        self._wallet_type = wallet_type

    @property
    def national_net_domestic_data(self):
        """
        Gets the national_net_domestic_data of this Ptsv2creditsProcessingInformation.
        Supplementary domestic transaction information provided by the acquirer for National Net Settlement Service (NNSS) transactions. NNSS is a settlement service that Visa provides. For transactions on CyberSource through VisaNet in countries that subscribe to NNSS: VisaNet clears transactions; VisaNet transfers funds to the acquirer after deducting processing fees and interchange fees. VisaNet settles transactions in the local pricing currency through a local financial institution. This field is supported only on CyberSource through VisaNet for domestic data in Colombia 

        :return: The national_net_domestic_data of this Ptsv2creditsProcessingInformation.
        :rtype: str
        """
        return self._national_net_domestic_data

    @national_net_domestic_data.setter
    def national_net_domestic_data(self, national_net_domestic_data):
        """
        Sets the national_net_domestic_data of this Ptsv2creditsProcessingInformation.
        Supplementary domestic transaction information provided by the acquirer for National Net Settlement Service (NNSS) transactions. NNSS is a settlement service that Visa provides. For transactions on CyberSource through VisaNet in countries that subscribe to NNSS: VisaNet clears transactions; VisaNet transfers funds to the acquirer after deducting processing fees and interchange fees. VisaNet settles transactions in the local pricing currency through a local financial institution. This field is supported only on CyberSource through VisaNet for domestic data in Colombia 

        :param national_net_domestic_data: The national_net_domestic_data of this Ptsv2creditsProcessingInformation.
        :type: str
        """
        if national_net_domestic_data is not None and len(national_net_domestic_data) > 123:
            raise ValueError("Invalid value for `national_net_domestic_data`, length must be less than or equal to `123`")

        self._national_net_domestic_data = national_net_domestic_data

    @property
    def network_routing_order(self):
        """
        Gets the network_routing_order of this Ptsv2creditsProcessingInformation.
        On PIN Debit Gateways: This U.S.-only field is optionally used by  participants (merchants and acquirers) to specify the network access priority. VisaNet checks to determine if there are issuer routing preferences for any of the networks specified by the sharing group code. If an issuer preference exists for one of the specified debit networks, VisaNet makes a routing selection based on the issuer’s preference. If an issuer preference exists for more than one of the specified debit networks, or if no issuer preference exists, VisaNet makes a selection based on the acquirer’s routing priorities.  #### PIN debit Priority order of the networks through which he transaction will be routed. Set this value to a series of one-character network codes in your preferred order. This is a list of the network codes:  | Network | Code | | --- | --- | | Accel | E | | AFFN | U | | Alaska Option | 3 | | CU24 | C | | Interlink | G | | Maestro | 8 | | NETS | P | | NYCE | F | | Pulse | H | | Shazam | 7 | | Star | M | | Visa | V |  For example, if the Star network is your first preference and Pulse is your second preference, set this field to a value of `MH`.  When you do not include this value in your PIN debit request, the list of network codes from your account is used. **Note** This field is supported only for businesses located in the U.S.  Optional field for PIN debit credit or PIN debit purchase. 

        :return: The network_routing_order of this Ptsv2creditsProcessingInformation.
        :rtype: str
        """
        return self._network_routing_order

    @network_routing_order.setter
    def network_routing_order(self, network_routing_order):
        """
        Sets the network_routing_order of this Ptsv2creditsProcessingInformation.
        On PIN Debit Gateways: This U.S.-only field is optionally used by  participants (merchants and acquirers) to specify the network access priority. VisaNet checks to determine if there are issuer routing preferences for any of the networks specified by the sharing group code. If an issuer preference exists for one of the specified debit networks, VisaNet makes a routing selection based on the issuer’s preference. If an issuer preference exists for more than one of the specified debit networks, or if no issuer preference exists, VisaNet makes a selection based on the acquirer’s routing priorities.  #### PIN debit Priority order of the networks through which he transaction will be routed. Set this value to a series of one-character network codes in your preferred order. This is a list of the network codes:  | Network | Code | | --- | --- | | Accel | E | | AFFN | U | | Alaska Option | 3 | | CU24 | C | | Interlink | G | | Maestro | 8 | | NETS | P | | NYCE | F | | Pulse | H | | Shazam | 7 | | Star | M | | Visa | V |  For example, if the Star network is your first preference and Pulse is your second preference, set this field to a value of `MH`.  When you do not include this value in your PIN debit request, the list of network codes from your account is used. **Note** This field is supported only for businesses located in the U.S.  Optional field for PIN debit credit or PIN debit purchase. 

        :param network_routing_order: The network_routing_order of this Ptsv2creditsProcessingInformation.
        :type: str
        """
        if network_routing_order is not None and len(network_routing_order) > 30:
            raise ValueError("Invalid value for `network_routing_order`, length must be less than or equal to `30`")

        self._network_routing_order = network_routing_order

    @property
    def recurring_options(self):
        """
        Gets the recurring_options of this Ptsv2creditsProcessingInformation.

        :return: The recurring_options of this Ptsv2creditsProcessingInformation.
        :rtype: Ptsv2paymentsidrefundsProcessingInformationRecurringOptions
        """
        return self._recurring_options

    @recurring_options.setter
    def recurring_options(self, recurring_options):
        """
        Sets the recurring_options of this Ptsv2creditsProcessingInformation.

        :param recurring_options: The recurring_options of this Ptsv2creditsProcessingInformation.
        :type: Ptsv2paymentsidrefundsProcessingInformationRecurringOptions
        """

        self._recurring_options = recurring_options

    @property
    def bank_transfer_options(self):
        """
        Gets the bank_transfer_options of this Ptsv2creditsProcessingInformation.

        :return: The bank_transfer_options of this Ptsv2creditsProcessingInformation.
        :rtype: Ptsv2creditsProcessingInformationBankTransferOptions
        """
        return self._bank_transfer_options

    @bank_transfer_options.setter
    def bank_transfer_options(self, bank_transfer_options):
        """
        Sets the bank_transfer_options of this Ptsv2creditsProcessingInformation.

        :param bank_transfer_options: The bank_transfer_options of this Ptsv2creditsProcessingInformation.
        :type: Ptsv2creditsProcessingInformationBankTransferOptions
        """

        self._bank_transfer_options = bank_transfer_options

    @property
    def purchase_options(self):
        """
        Gets the purchase_options of this Ptsv2creditsProcessingInformation.

        :return: The purchase_options of this Ptsv2creditsProcessingInformation.
        :rtype: Ptsv2creditsProcessingInformationPurchaseOptions
        """
        return self._purchase_options

    @purchase_options.setter
    def purchase_options(self, purchase_options):
        """
        Sets the purchase_options of this Ptsv2creditsProcessingInformation.

        :param purchase_options: The purchase_options of this Ptsv2creditsProcessingInformation.
        :type: Ptsv2creditsProcessingInformationPurchaseOptions
        """

        self._purchase_options = purchase_options

    @property
    def electronic_benefits_transfer(self):
        """
        Gets the electronic_benefits_transfer of this Ptsv2creditsProcessingInformation.

        :return: The electronic_benefits_transfer of this Ptsv2creditsProcessingInformation.
        :rtype: Ptsv2creditsProcessingInformationElectronicBenefitsTransfer
        """
        return self._electronic_benefits_transfer

    @electronic_benefits_transfer.setter
    def electronic_benefits_transfer(self, electronic_benefits_transfer):
        """
        Sets the electronic_benefits_transfer of this Ptsv2creditsProcessingInformation.

        :param electronic_benefits_transfer: The electronic_benefits_transfer of this Ptsv2creditsProcessingInformation.
        :type: Ptsv2creditsProcessingInformationElectronicBenefitsTransfer
        """

        self._electronic_benefits_transfer = electronic_benefits_transfer

    @property
    def loan_options(self):
        """
        Gets the loan_options of this Ptsv2creditsProcessingInformation.

        :return: The loan_options of this Ptsv2creditsProcessingInformation.
        :rtype: Ptsv2paymentsProcessingInformationLoanOptions
        """
        return self._loan_options

    @loan_options.setter
    def loan_options(self, loan_options):
        """
        Sets the loan_options of this Ptsv2creditsProcessingInformation.

        :param loan_options: The loan_options of this Ptsv2creditsProcessingInformation.
        :type: Ptsv2paymentsProcessingInformationLoanOptions
        """

        self._loan_options = loan_options

    @property
    def japan_payment_options(self):
        """
        Gets the japan_payment_options of this Ptsv2creditsProcessingInformation.

        :return: The japan_payment_options of this Ptsv2creditsProcessingInformation.
        :rtype: Ptsv2creditsProcessingInformationJapanPaymentOptions
        """
        return self._japan_payment_options

    @japan_payment_options.setter
    def japan_payment_options(self, japan_payment_options):
        """
        Sets the japan_payment_options of this Ptsv2creditsProcessingInformation.

        :param japan_payment_options: The japan_payment_options of this Ptsv2creditsProcessingInformation.
        :type: Ptsv2creditsProcessingInformationJapanPaymentOptions
        """

        self._japan_payment_options = japan_payment_options

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2creditsProcessingInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ticket_number': 'str',
        'passenger_name': 'str',
        'connected_ticket_number': 'str',
        'credit_reason_indicator': 'str',
        'service': 'list[Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformationService]'
    }

    attribute_map = {
        'ticket_number': 'ticketNumber',
        'passenger_name': 'passengerName',
        'connected_ticket_number': 'connectedTicketNumber',
        'credit_reason_indicator': 'creditReasonIndicator',
        'service': 'service'
    }

    def __init__(self, ticket_number=None, passenger_name=None, connected_ticket_number=None, credit_reason_indicator=None, service=None):
        """
        Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformation - a model defined in Swagger
        """

        self._ticket_number = None
        self._passenger_name = None
        self._connected_ticket_number = None
        self._credit_reason_indicator = None
        self._service = None

        if ticket_number is not None:
          self.ticket_number = ticket_number
        if passenger_name is not None:
          self.passenger_name = passenger_name
        if connected_ticket_number is not None:
          self.connected_ticket_number = connected_ticket_number
        if credit_reason_indicator is not None:
          self.credit_reason_indicator = credit_reason_indicator
        if service is not None:
          self.service = service

    @property
    def ticket_number(self):
        """
        Gets the ticket_number of this Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformation.
        Ticket number, which consists of the carrier code, form, and serial number, without the check digit. **Important** This field is required in the U.S. in order for you to qualify for either the custom payment service (CPS) or the electronic interchange reimbursement fee (EIRF) program. Format: English characters only. Optional field for ancillary services. 

        :return: The ticket_number of this Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformation.
        :rtype: str
        """
        return self._ticket_number

    @ticket_number.setter
    def ticket_number(self, ticket_number):
        """
        Sets the ticket_number of this Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformation.
        Ticket number, which consists of the carrier code, form, and serial number, without the check digit. **Important** This field is required in the U.S. in order for you to qualify for either the custom payment service (CPS) or the electronic interchange reimbursement fee (EIRF) program. Format: English characters only. Optional field for ancillary services. 

        :param ticket_number: The ticket_number of this Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformation.
        :type: str
        """
        if ticket_number is not None and len(ticket_number) > 15:
            raise ValueError("Invalid value for `ticket_number`, length must be less than or equal to `15`")

        self._ticket_number = ticket_number

    @property
    def passenger_name(self):
        """
        Gets the passenger_name of this Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformation.
        Name of the passenger. If the passenger’s name is not available, this value is the cardholder’s name. If neither the passenger’s name nor the cardholder’s name is available, this value is a description of the ancillary purchase. **Important** This field is required in the U.S. in order for you to qualify for either the custom payment service (CPS) or the electronic interchange reimbursement fee (EIRF) program. Format: English characters only. Optional field for ancillary service. 

        :return: The passenger_name of this Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformation.
        :rtype: str
        """
        return self._passenger_name

    @passenger_name.setter
    def passenger_name(self, passenger_name):
        """
        Sets the passenger_name of this Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformation.
        Name of the passenger. If the passenger’s name is not available, this value is the cardholder’s name. If neither the passenger’s name nor the cardholder’s name is available, this value is a description of the ancillary purchase. **Important** This field is required in the U.S. in order for you to qualify for either the custom payment service (CPS) or the electronic interchange reimbursement fee (EIRF) program. Format: English characters only. Optional field for ancillary service. 

        :param passenger_name: The passenger_name of this Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformation.
        :type: str
        """
        if passenger_name is not None and len(passenger_name) > 20:
            raise ValueError("Invalid value for `passenger_name`, length must be less than or equal to `20`")

        self._passenger_name = passenger_name

    @property
    def connected_ticket_number(self):
        """
        Gets the connected_ticket_number of this Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformation.
        Number for the airline ticket to which the ancillary purchase is connected.  If this purchase has a connection or relationship to another purchase such as a baggage fee for a passenger transport ticket, this field must contain the ticket number for the other purchase.  For a stand-alone purchase, the value for this field must be the same as the value for the `travelInformation.transit.airline.ancillaryInformation.ticketNumber` field. **Important** This field is required in the U.S. in order for you to qualify for either the custom payment service (CPS) or the electronic interchange reimbursement fee (EIRF) program. Format: English characters only. Optional request field for ancillary services. 

        :return: The connected_ticket_number of this Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformation.
        :rtype: str
        """
        return self._connected_ticket_number

    @connected_ticket_number.setter
    def connected_ticket_number(self, connected_ticket_number):
        """
        Sets the connected_ticket_number of this Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformation.
        Number for the airline ticket to which the ancillary purchase is connected.  If this purchase has a connection or relationship to another purchase such as a baggage fee for a passenger transport ticket, this field must contain the ticket number for the other purchase.  For a stand-alone purchase, the value for this field must be the same as the value for the `travelInformation.transit.airline.ancillaryInformation.ticketNumber` field. **Important** This field is required in the U.S. in order for you to qualify for either the custom payment service (CPS) or the electronic interchange reimbursement fee (EIRF) program. Format: English characters only. Optional request field for ancillary services. 

        :param connected_ticket_number: The connected_ticket_number of this Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformation.
        :type: str
        """
        if connected_ticket_number is not None and len(connected_ticket_number) > 15:
            raise ValueError("Invalid value for `connected_ticket_number`, length must be less than or equal to `15`")

        self._connected_ticket_number = connected_ticket_number

    @property
    def credit_reason_indicator(self):
        """
        Gets the credit_reason_indicator of this Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformation.
        Reason for the credit. Possible values: - `A`: Cancellation of the ancillary passenger transport purchase. - `B`: Cancellation of the airline ticket and the passenger transport ancillary purchase. - `C`: Cancellation of the airline ticket. - `O`: Other. - `P`: Partial refund of the airline ticket. Format: English characters only. Optional field for ancillary services. 

        :return: The credit_reason_indicator of this Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformation.
        :rtype: str
        """
        return self._credit_reason_indicator

    @credit_reason_indicator.setter
    def credit_reason_indicator(self, credit_reason_indicator):
        """
        Sets the credit_reason_indicator of this Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformation.
        Reason for the credit. Possible values: - `A`: Cancellation of the ancillary passenger transport purchase. - `B`: Cancellation of the airline ticket and the passenger transport ancillary purchase. - `C`: Cancellation of the airline ticket. - `O`: Other. - `P`: Partial refund of the airline ticket. Format: English characters only. Optional field for ancillary services. 

        :param credit_reason_indicator: The credit_reason_indicator of this Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformation.
        :type: str
        """
        if credit_reason_indicator is not None and len(credit_reason_indicator) > 15:
            raise ValueError("Invalid value for `credit_reason_indicator`, length must be less than or equal to `15`")

        self._credit_reason_indicator = credit_reason_indicator

    @property
    def service(self):
        """
        Gets the service of this Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformation.

        :return: The service of this Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformation.
        :rtype: list[Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformationService]
        """
        return self._service

    @service.setter
    def service(self, service):
        """
        Sets the service of this Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformation.

        :param service: The service of this Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformation.
        :type: list[Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformationService]
        """

        self._service = service

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
